#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MerchantLimit(object):

    def __init__(self):
        self._limit_merchant_list = None
        self._limit_type = None

    @property
    def limit_merchant_list(self):
        return self._limit_merchant_list

    @limit_merchant_list.setter
    def limit_merchant_list(self, value):
        if isinstance(value, list):
            self._limit_merchant_list = list()
            for i in value:
                self._limit_merchant_list.append(i)
    @property
    def limit_type(self):
        return self._limit_type

    @limit_type.setter
    def limit_type(self, value):
        self._limit_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.limit_merchant_list:
            if isinstance(self.limit_merchant_list, list):
                for i in range(0, len(self.limit_merchant_list)):
                    element = self.limit_merchant_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.limit_merchant_list[i] = element.to_alipay_dict()
            if hasattr(self.limit_merchant_list, 'to_alipay_dict'):
                params['limit_merchant_list'] = self.limit_merchant_list.to_alipay_dict()
            else:
                params['limit_merchant_list'] = self.limit_merchant_list
        if self.limit_type:
            if hasattr(self.limit_type, 'to_alipay_dict'):
                params['limit_type'] = self.limit_type.to_alipay_dict()
            else:
                params['limit_type'] = self.limit_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MerchantLimit()
        if 'limit_merchant_list' in d:
            o.limit_merchant_list = d['limit_merchant_list']
        if 'limit_type' in d:
            o.limit_type = d['limit_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CourseSKUInfo(object):

    def __init__(self):
        self._course_num = None
        self._cur_price = None
        self._ori_price = None
        self._out_sku_id = None
        self._stock_num = None

    @property
    def course_num(self):
        return self._course_num

    @course_num.setter
    def course_num(self, value):
        self._course_num = value
    @property
    def cur_price(self):
        return self._cur_price

    @cur_price.setter
    def cur_price(self, value):
        self._cur_price = value
    @property
    def ori_price(self):
        return self._ori_price

    @ori_price.setter
    def ori_price(self, value):
        self._ori_price = value
    @property
    def out_sku_id(self):
        return self._out_sku_id

    @out_sku_id.setter
    def out_sku_id(self, value):
        self._out_sku_id = value
    @property
    def stock_num(self):
        return self._stock_num

    @stock_num.setter
    def stock_num(self, value):
        self._stock_num = value


    def to_alipay_dict(self):
        params = dict()
        if self.course_num:
            if hasattr(self.course_num, 'to_alipay_dict'):
                params['course_num'] = self.course_num.to_alipay_dict()
            else:
                params['course_num'] = self.course_num
        if self.cur_price:
            if hasattr(self.cur_price, 'to_alipay_dict'):
                params['cur_price'] = self.cur_price.to_alipay_dict()
            else:
                params['cur_price'] = self.cur_price
        if self.ori_price:
            if hasattr(self.ori_price, 'to_alipay_dict'):
                params['ori_price'] = self.ori_price.to_alipay_dict()
            else:
                params['ori_price'] = self.ori_price
        if self.out_sku_id:
            if hasattr(self.out_sku_id, 'to_alipay_dict'):
                params['out_sku_id'] = self.out_sku_id.to_alipay_dict()
            else:
                params['out_sku_id'] = self.out_sku_id
        if self.stock_num:
            if hasattr(self.stock_num, 'to_alipay_dict'):
                params['stock_num'] = self.stock_num.to_alipay_dict()
            else:
                params['stock_num'] = self.stock_num
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CourseSKUInfo()
        if 'course_num' in d:
            o.course_num = d['course_num']
        if 'cur_price' in d:
            o.cur_price = d['cur_price']
        if 'ori_price' in d:
            o.ori_price = d['ori_price']
        if 'out_sku_id' in d:
            o.out_sku_id = d['out_sku_id']
        if 'stock_num' in d:
            o.stock_num = d['stock_num']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.RiskFinishLabel import RiskFinishLabel


class RiskFinishInfo(object):

    def __init__(self):
        self._finish_label = None
        self._finish_type = None
        self._task_id = None

    @property
    def finish_label(self):
        return self._finish_label

    @finish_label.setter
    def finish_label(self, value):
        if isinstance(value, list):
            self._finish_label = list()
            for i in value:
                if isinstance(i, RiskFinishLabel):
                    self._finish_label.append(i)
                else:
                    self._finish_label.append(RiskFinishLabel.from_alipay_dict(i))
    @property
    def finish_type(self):
        return self._finish_type

    @finish_type.setter
    def finish_type(self, value):
        self._finish_type = value
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.finish_label:
            if isinstance(self.finish_label, list):
                for i in range(0, len(self.finish_label)):
                    element = self.finish_label[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.finish_label[i] = element.to_alipay_dict()
            if hasattr(self.finish_label, 'to_alipay_dict'):
                params['finish_label'] = self.finish_label.to_alipay_dict()
            else:
                params['finish_label'] = self.finish_label
        if self.finish_type:
            if hasattr(self.finish_type, 'to_alipay_dict'):
                params['finish_type'] = self.finish_type.to_alipay_dict()
            else:
                params['finish_type'] = self.finish_type
        if self.task_id:
            if hasattr(self.task_id, 'to_alipay_dict'):
                params['task_id'] = self.task_id.to_alipay_dict()
            else:
                params['task_id'] = self.task_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RiskFinishInfo()
        if 'finish_label' in d:
            o.finish_label = d['finish_label']
        if 'finish_type' in d:
            o.finish_type = d['finish_type']
        if 'task_id' in d:
            o.task_id = d['task_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceAuthSignModel(object):

    def __init__(self):
        self._authorization_type = None
        self._extend_fields = None
        self._m_short_name = None
        self._open_id = None
        self._user_id = None

    @property
    def authorization_type(self):
        return self._authorization_type

    @authorization_type.setter
    def authorization_type(self, value):
        self._authorization_type = value
    @property
    def extend_fields(self):
        return self._extend_fields

    @extend_fields.setter
    def extend_fields(self, value):
        self._extend_fields = value
    @property
    def m_short_name(self):
        return self._m_short_name

    @m_short_name.setter
    def m_short_name(self, value):
        self._m_short_name = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.authorization_type:
            if hasattr(self.authorization_type, 'to_alipay_dict'):
                params['authorization_type'] = self.authorization_type.to_alipay_dict()
            else:
                params['authorization_type'] = self.authorization_type
        if self.extend_fields:
            if hasattr(self.extend_fields, 'to_alipay_dict'):
                params['extend_fields'] = self.extend_fields.to_alipay_dict()
            else:
                params['extend_fields'] = self.extend_fields
        if self.m_short_name:
            if hasattr(self.m_short_name, 'to_alipay_dict'):
                params['m_short_name'] = self.m_short_name.to_alipay_dict()
            else:
                params['m_short_name'] = self.m_short_name
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceAuthSignModel()
        if 'authorization_type' in d:
            o.authorization_type = d['authorization_type']
        if 'extend_fields' in d:
            o.extend_fields = d['extend_fields']
        if 'm_short_name' in d:
            o.m_short_name = d['m_short_name']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.EcProtocolInfo import EcProtocolInfo


class EcContractInfo(object):

    def __init__(self):
        self._cancel_time = None
        self._contract_id = None
        self._contract_title = None
        self._first_party_id = None
        self._first_party_name = None
        self._out_request_no = None
        self._protocol_info_list = None
        self._scene = None
        self._second_party_id = None
        self._second_party_name = None
        self._sign_time = None
        self._status = None

    @property
    def cancel_time(self):
        return self._cancel_time

    @cancel_time.setter
    def cancel_time(self, value):
        self._cancel_time = value
    @property
    def contract_id(self):
        return self._contract_id

    @contract_id.setter
    def contract_id(self, value):
        self._contract_id = value
    @property
    def contract_title(self):
        return self._contract_title

    @contract_title.setter
    def contract_title(self, value):
        self._contract_title = value
    @property
    def first_party_id(self):
        return self._first_party_id

    @first_party_id.setter
    def first_party_id(self, value):
        self._first_party_id = value
    @property
    def first_party_name(self):
        return self._first_party_name

    @first_party_name.setter
    def first_party_name(self, value):
        self._first_party_name = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def protocol_info_list(self):
        return self._protocol_info_list

    @protocol_info_list.setter
    def protocol_info_list(self, value):
        if isinstance(value, list):
            self._protocol_info_list = list()
            for i in value:
                if isinstance(i, EcProtocolInfo):
                    self._protocol_info_list.append(i)
                else:
                    self._protocol_info_list.append(EcProtocolInfo.from_alipay_dict(i))
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value
    @property
    def second_party_id(self):
        return self._second_party_id

    @second_party_id.setter
    def second_party_id(self, value):
        self._second_party_id = value
    @property
    def second_party_name(self):
        return self._second_party_name

    @second_party_name.setter
    def second_party_name(self, value):
        self._second_party_name = value
    @property
    def sign_time(self):
        return self._sign_time

    @sign_time.setter
    def sign_time(self, value):
        self._sign_time = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.cancel_time:
            if hasattr(self.cancel_time, 'to_alipay_dict'):
                params['cancel_time'] = self.cancel_time.to_alipay_dict()
            else:
                params['cancel_time'] = self.cancel_time
        if self.contract_id:
            if hasattr(self.contract_id, 'to_alipay_dict'):
                params['contract_id'] = self.contract_id.to_alipay_dict()
            else:
                params['contract_id'] = self.contract_id
        if self.contract_title:
            if hasattr(self.contract_title, 'to_alipay_dict'):
                params['contract_title'] = self.contract_title.to_alipay_dict()
            else:
                params['contract_title'] = self.contract_title
        if self.first_party_id:
            if hasattr(self.first_party_id, 'to_alipay_dict'):
                params['first_party_id'] = self.first_party_id.to_alipay_dict()
            else:
                params['first_party_id'] = self.first_party_id
        if self.first_party_name:
            if hasattr(self.first_party_name, 'to_alipay_dict'):
                params['first_party_name'] = self.first_party_name.to_alipay_dict()
            else:
                params['first_party_name'] = self.first_party_name
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.protocol_info_list:
            if isinstance(self.protocol_info_list, list):
                for i in range(0, len(self.protocol_info_list)):
                    element = self.protocol_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.protocol_info_list[i] = element.to_alipay_dict()
            if hasattr(self.protocol_info_list, 'to_alipay_dict'):
                params['protocol_info_list'] = self.protocol_info_list.to_alipay_dict()
            else:
                params['protocol_info_list'] = self.protocol_info_list
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        if self.second_party_id:
            if hasattr(self.second_party_id, 'to_alipay_dict'):
                params['second_party_id'] = self.second_party_id.to_alipay_dict()
            else:
                params['second_party_id'] = self.second_party_id
        if self.second_party_name:
            if hasattr(self.second_party_name, 'to_alipay_dict'):
                params['second_party_name'] = self.second_party_name.to_alipay_dict()
            else:
                params['second_party_name'] = self.second_party_name
        if self.sign_time:
            if hasattr(self.sign_time, 'to_alipay_dict'):
                params['sign_time'] = self.sign_time.to_alipay_dict()
            else:
                params['sign_time'] = self.sign_time
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EcContractInfo()
        if 'cancel_time' in d:
            o.cancel_time = d['cancel_time']
        if 'contract_id' in d:
            o.contract_id = d['contract_id']
        if 'contract_title' in d:
            o.contract_title = d['contract_title']
        if 'first_party_id' in d:
            o.first_party_id = d['first_party_id']
        if 'first_party_name' in d:
            o.first_party_name = d['first_party_name']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'protocol_info_list' in d:
            o.protocol_info_list = d['protocol_info_list']
        if 'scene' in d:
            o.scene = d['scene']
        if 'second_party_id' in d:
            o.second_party_id = d['second_party_id']
        if 'second_party_name' in d:
            o.second_party_name = d['second_party_name']
        if 'sign_time' in d:
            o.sign_time = d['sign_time']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityDanielTestQueryModel(object):

    def __init__(self):
        self._input_query = None

    @property
    def input_query(self):
        return self._input_query

    @input_query.setter
    def input_query(self, value):
        self._input_query = value


    def to_alipay_dict(self):
        params = dict()
        if self.input_query:
            if hasattr(self.input_query, 'to_alipay_dict'):
                params['input_query'] = self.input_query.to_alipay_dict()
            else:
                params['input_query'] = self.input_query
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityDanielTestQueryModel()
        if 'input_query' in d:
            o.input_query = d['input_query']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiCateringPosPaymodeCreateModel(object):

    def __init__(self):
        self._fixed_amount = None
        self._fixed_switch = None
        self._income_ratio = None
        self._pay_name = None
        self._shop_id = None

    @property
    def fixed_amount(self):
        return self._fixed_amount

    @fixed_amount.setter
    def fixed_amount(self, value):
        self._fixed_amount = value
    @property
    def fixed_switch(self):
        return self._fixed_switch

    @fixed_switch.setter
    def fixed_switch(self, value):
        self._fixed_switch = value
    @property
    def income_ratio(self):
        return self._income_ratio

    @income_ratio.setter
    def income_ratio(self, value):
        self._income_ratio = value
    @property
    def pay_name(self):
        return self._pay_name

    @pay_name.setter
    def pay_name(self, value):
        self._pay_name = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.fixed_amount:
            if hasattr(self.fixed_amount, 'to_alipay_dict'):
                params['fixed_amount'] = self.fixed_amount.to_alipay_dict()
            else:
                params['fixed_amount'] = self.fixed_amount
        if self.fixed_switch:
            if hasattr(self.fixed_switch, 'to_alipay_dict'):
                params['fixed_switch'] = self.fixed_switch.to_alipay_dict()
            else:
                params['fixed_switch'] = self.fixed_switch
        if self.income_ratio:
            if hasattr(self.income_ratio, 'to_alipay_dict'):
                params['income_ratio'] = self.income_ratio.to_alipay_dict()
            else:
                params['income_ratio'] = self.income_ratio
        if self.pay_name:
            if hasattr(self.pay_name, 'to_alipay_dict'):
                params['pay_name'] = self.pay_name.to_alipay_dict()
            else:
                params['pay_name'] = self.pay_name
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringPosPaymodeCreateModel()
        if 'fixed_amount' in d:
            o.fixed_amount = d['fixed_amount']
        if 'fixed_switch' in d:
            o.fixed_switch = d['fixed_switch']
        if 'income_ratio' in d:
            o.income_ratio = d['income_ratio']
        if 'pay_name' in d:
            o.pay_name = d['pay_name']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GoodsCategoryResult(object):

    def __init__(self):
        self._category_code = None
        self._category_name = None
        self._level = None
        self._parent_category_code = None

    @property
    def category_code(self):
        return self._category_code

    @category_code.setter
    def category_code(self, value):
        self._category_code = value
    @property
    def category_name(self):
        return self._category_name

    @category_name.setter
    def category_name(self, value):
        self._category_name = value
    @property
    def level(self):
        return self._level

    @level.setter
    def level(self, value):
        self._level = value
    @property
    def parent_category_code(self):
        return self._parent_category_code

    @parent_category_code.setter
    def parent_category_code(self, value):
        self._parent_category_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.category_code:
            if hasattr(self.category_code, 'to_alipay_dict'):
                params['category_code'] = self.category_code.to_alipay_dict()
            else:
                params['category_code'] = self.category_code
        if self.category_name:
            if hasattr(self.category_name, 'to_alipay_dict'):
                params['category_name'] = self.category_name.to_alipay_dict()
            else:
                params['category_name'] = self.category_name
        if self.level:
            if hasattr(self.level, 'to_alipay_dict'):
                params['level'] = self.level.to_alipay_dict()
            else:
                params['level'] = self.level
        if self.parent_category_code:
            if hasattr(self.parent_category_code, 'to_alipay_dict'):
                params['parent_category_code'] = self.parent_category_code.to_alipay_dict()
            else:
                params['parent_category_code'] = self.parent_category_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GoodsCategoryResult()
        if 'category_code' in d:
            o.category_code = d['category_code']
        if 'category_name' in d:
            o.category_name = d['category_name']
        if 'level' in d:
            o.level = d['level']
        if 'parent_category_code' in d:
            o.parent_category_code = d['parent_category_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayContract(object):

    def __init__(self):
        self._alipay_open_id = None
        self._alipay_user_id = None
        self._contract_content = None
        self._end_time = None
        self._page_url = None
        self._start_time = None
        self._subscribe = None

    @property
    def alipay_open_id(self):
        return self._alipay_open_id

    @alipay_open_id.setter
    def alipay_open_id(self, value):
        self._alipay_open_id = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def contract_content(self):
        return self._contract_content

    @contract_content.setter
    def contract_content(self, value):
        self._contract_content = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def page_url(self):
        return self._page_url

    @page_url.setter
    def page_url(self, value):
        self._page_url = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def subscribe(self):
        return self._subscribe

    @subscribe.setter
    def subscribe(self, value):
        self._subscribe = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_open_id:
            if hasattr(self.alipay_open_id, 'to_alipay_dict'):
                params['alipay_open_id'] = self.alipay_open_id.to_alipay_dict()
            else:
                params['alipay_open_id'] = self.alipay_open_id
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.contract_content:
            if hasattr(self.contract_content, 'to_alipay_dict'):
                params['contract_content'] = self.contract_content.to_alipay_dict()
            else:
                params['contract_content'] = self.contract_content
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.page_url:
            if hasattr(self.page_url, 'to_alipay_dict'):
                params['page_url'] = self.page_url.to_alipay_dict()
            else:
                params['page_url'] = self.page_url
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.subscribe:
            if hasattr(self.subscribe, 'to_alipay_dict'):
                params['subscribe'] = self.subscribe.to_alipay_dict()
            else:
                params['subscribe'] = self.subscribe
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayContract()
        if 'alipay_open_id' in d:
            o.alipay_open_id = d['alipay_open_id']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'contract_content' in d:
            o.contract_content = d['contract_content']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'page_url' in d:
            o.page_url = d['page_url']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'subscribe' in d:
            o.subscribe = d['subscribe']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.LogisticsAccountStatusDTO import LogisticsAccountStatusDTO


class AlipayOpenAppTestHahaQueryModel(object):

    def __init__(self):
        self._test_one = None
        self._test_three = None
        self._test_two = None

    @property
    def test_one(self):
        return self._test_one

    @test_one.setter
    def test_one(self, value):
        self._test_one = value
    @property
    def test_three(self):
        return self._test_three

    @test_three.setter
    def test_three(self, value):
        if isinstance(value, LogisticsAccountStatusDTO):
            self._test_three = value
        else:
            self._test_three = LogisticsAccountStatusDTO.from_alipay_dict(value)
    @property
    def test_two(self):
        return self._test_two

    @test_two.setter
    def test_two(self, value):
        self._test_two = value


    def to_alipay_dict(self):
        params = dict()
        if self.test_one:
            if hasattr(self.test_one, 'to_alipay_dict'):
                params['test_one'] = self.test_one.to_alipay_dict()
            else:
                params['test_one'] = self.test_one
        if self.test_three:
            if hasattr(self.test_three, 'to_alipay_dict'):
                params['test_three'] = self.test_three.to_alipay_dict()
            else:
                params['test_three'] = self.test_three
        if self.test_two:
            if hasattr(self.test_two, 'to_alipay_dict'):
                params['test_two'] = self.test_two.to_alipay_dict()
            else:
                params['test_two'] = self.test_two
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppTestHahaQueryModel()
        if 'test_one' in d:
            o.test_one = d['test_one']
        if 'test_three' in d:
            o.test_three = d['test_three']
        if 'test_two' in d:
            o.test_two = d['test_two']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ItemInventory(object):

    def __init__(self):
        self._ext_prop = None
        self._external_item_id = None
        self._inventory = None

    @property
    def ext_prop(self):
        return self._ext_prop

    @ext_prop.setter
    def ext_prop(self, value):
        self._ext_prop = value
    @property
    def external_item_id(self):
        return self._external_item_id

    @external_item_id.setter
    def external_item_id(self, value):
        self._external_item_id = value
    @property
    def inventory(self):
        return self._inventory

    @inventory.setter
    def inventory(self, value):
        self._inventory = value


    def to_alipay_dict(self):
        params = dict()
        if self.ext_prop:
            if hasattr(self.ext_prop, 'to_alipay_dict'):
                params['ext_prop'] = self.ext_prop.to_alipay_dict()
            else:
                params['ext_prop'] = self.ext_prop
        if self.external_item_id:
            if hasattr(self.external_item_id, 'to_alipay_dict'):
                params['external_item_id'] = self.external_item_id.to_alipay_dict()
            else:
                params['external_item_id'] = self.external_item_id
        if self.inventory:
            if hasattr(self.inventory, 'to_alipay_dict'):
                params['inventory'] = self.inventory.to_alipay_dict()
            else:
                params['inventory'] = self.inventory
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ItemInventory()
        if 'ext_prop' in d:
            o.ext_prop = d['ext_prop']
        if 'external_item_id' in d:
            o.external_item_id = d['external_item_id']
        if 'inventory' in d:
            o.inventory = d['inventory']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCreditPeUserAuthApplyResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditPeUserAuthApplyResponse, self).__init__()
        self._auth_code = None
        self._error_scope = None
        self._scope = None
        self._state = None

    @property
    def auth_code(self):
        return self._auth_code

    @auth_code.setter
    def auth_code(self, value):
        self._auth_code = value
    @property
    def error_scope(self):
        return self._error_scope

    @error_scope.setter
    def error_scope(self, value):
        self._error_scope = value
    @property
    def scope(self):
        return self._scope

    @scope.setter
    def scope(self, value):
        self._scope = value
    @property
    def state(self):
        return self._state

    @state.setter
    def state(self, value):
        self._state = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditPeUserAuthApplyResponse, self).parse_response_content(response_content)
        if 'auth_code' in response:
            self.auth_code = response['auth_code']
        if 'error_scope' in response:
            self.error_scope = response['error_scope']
        if 'scope' in response:
            self.scope = response['scope']
        if 'state' in response:
            self.state = response['state']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCreditCreditriskDataPutModel(object):

    def __init__(self):
        self._category = None
        self._dataorgid = None
        self._dataprovider = None
        self._entitycode = None
        self._entityname = None
        self._entitytype = None
        self._objectcontent = None
        self._openid = None
        self._taskid = None

    @property
    def category(self):
        return self._category

    @category.setter
    def category(self, value):
        self._category = value
    @property
    def dataorgid(self):
        return self._dataorgid

    @dataorgid.setter
    def dataorgid(self, value):
        self._dataorgid = value
    @property
    def dataprovider(self):
        return self._dataprovider

    @dataprovider.setter
    def dataprovider(self, value):
        self._dataprovider = value
    @property
    def entitycode(self):
        return self._entitycode

    @entitycode.setter
    def entitycode(self, value):
        self._entitycode = value
    @property
    def entityname(self):
        return self._entityname

    @entityname.setter
    def entityname(self, value):
        self._entityname = value
    @property
    def entitytype(self):
        return self._entitytype

    @entitytype.setter
    def entitytype(self, value):
        self._entitytype = value
    @property
    def objectcontent(self):
        return self._objectcontent

    @objectcontent.setter
    def objectcontent(self, value):
        self._objectcontent = value
    @property
    def openid(self):
        return self._openid

    @openid.setter
    def openid(self, value):
        self._openid = value
    @property
    def taskid(self):
        return self._taskid

    @taskid.setter
    def taskid(self, value):
        self._taskid = value


    def to_alipay_dict(self):
        params = dict()
        if self.category:
            if hasattr(self.category, 'to_alipay_dict'):
                params['category'] = self.category.to_alipay_dict()
            else:
                params['category'] = self.category
        if self.dataorgid:
            if hasattr(self.dataorgid, 'to_alipay_dict'):
                params['dataorgid'] = self.dataorgid.to_alipay_dict()
            else:
                params['dataorgid'] = self.dataorgid
        if self.dataprovider:
            if hasattr(self.dataprovider, 'to_alipay_dict'):
                params['dataprovider'] = self.dataprovider.to_alipay_dict()
            else:
                params['dataprovider'] = self.dataprovider
        if self.entitycode:
            if hasattr(self.entitycode, 'to_alipay_dict'):
                params['entitycode'] = self.entitycode.to_alipay_dict()
            else:
                params['entitycode'] = self.entitycode
        if self.entityname:
            if hasattr(self.entityname, 'to_alipay_dict'):
                params['entityname'] = self.entityname.to_alipay_dict()
            else:
                params['entityname'] = self.entityname
        if self.entitytype:
            if hasattr(self.entitytype, 'to_alipay_dict'):
                params['entitytype'] = self.entitytype.to_alipay_dict()
            else:
                params['entitytype'] = self.entitytype
        if self.objectcontent:
            if hasattr(self.objectcontent, 'to_alipay_dict'):
                params['objectcontent'] = self.objectcontent.to_alipay_dict()
            else:
                params['objectcontent'] = self.objectcontent
        if self.openid:
            if hasattr(self.openid, 'to_alipay_dict'):
                params['openid'] = self.openid.to_alipay_dict()
            else:
                params['openid'] = self.openid
        if self.taskid:
            if hasattr(self.taskid, 'to_alipay_dict'):
                params['taskid'] = self.taskid.to_alipay_dict()
            else:
                params['taskid'] = self.taskid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCreditCreditriskDataPutModel()
        if 'category' in d:
            o.category = d['category']
        if 'dataorgid' in d:
            o.dataorgid = d['dataorgid']
        if 'dataprovider' in d:
            o.dataprovider = d['dataprovider']
        if 'entitycode' in d:
            o.entitycode = d['entitycode']
        if 'entityname' in d:
            o.entityname = d['entityname']
        if 'entitytype' in d:
            o.entitytype = d['entitytype']
        if 'objectcontent' in d:
            o.objectcontent = d['objectcontent']
        if 'openid' in d:
            o.openid = d['openid']
        if 'taskid' in d:
            o.taskid = d['taskid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ChannelPutPlanCrowdDTO import ChannelPutPlanCrowdDTO


class ChannelPutPlanDetailDTO(object):

    def __init__(self):
        self._activity_page = None
        self._activity_page_name = None
        self._activity_page_url = None
        self._activity_title = None
        self._benefit_desc = None
        self._bill_way = None
        self._channel_code = None
        self._channel_id = None
        self._channel_name = None
        self._creator_id = None
        self._creator_name = None
        self._crowd_ids = None
        self._crowd_info = None
        self._customize_page = None
        self._detail_page_title = None
        self._gmt_create = None
        self._gmt_modified = None
        self._gmt_plan_end = None
        self._gmt_plan_start = None
        self._id = None
        self._modifier_id = None
        self._modifier_name = None
        self._name = None
        self._page_type = None
        self._pic_url = None
        self._reject_reason = None
        self._rule_text = None
        self._status = None
        self._task_id = None
        self._task_name = None
        self._tenant_code = None

    @property
    def activity_page(self):
        return self._activity_page

    @activity_page.setter
    def activity_page(self, value):
        self._activity_page = value
    @property
    def activity_page_name(self):
        return self._activity_page_name

    @activity_page_name.setter
    def activity_page_name(self, value):
        self._activity_page_name = value
    @property
    def activity_page_url(self):
        return self._activity_page_url

    @activity_page_url.setter
    def activity_page_url(self, value):
        self._activity_page_url = value
    @property
    def activity_title(self):
        return self._activity_title

    @activity_title.setter
    def activity_title(self, value):
        self._activity_title = value
    @property
    def benefit_desc(self):
        return self._benefit_desc

    @benefit_desc.setter
    def benefit_desc(self, value):
        self._benefit_desc = value
    @property
    def bill_way(self):
        return self._bill_way

    @bill_way.setter
    def bill_way(self, value):
        self._bill_way = value
    @property
    def channel_code(self):
        return self._channel_code

    @channel_code.setter
    def channel_code(self, value):
        self._channel_code = value
    @property
    def channel_id(self):
        return self._channel_id

    @channel_id.setter
    def channel_id(self, value):
        self._channel_id = value
    @property
    def channel_name(self):
        return self._channel_name

    @channel_name.setter
    def channel_name(self, value):
        self._channel_name = value
    @property
    def creator_id(self):
        return self._creator_id

    @creator_id.setter
    def creator_id(self, value):
        self._creator_id = value
    @property
    def creator_name(self):
        return self._creator_name

    @creator_name.setter
    def creator_name(self, value):
        self._creator_name = value
    @property
    def crowd_ids(self):
        return self._crowd_ids

    @crowd_ids.setter
    def crowd_ids(self, value):
        if isinstance(value, list):
            self._crowd_ids = list()
            for i in value:
                self._crowd_ids.append(i)
    @property
    def crowd_info(self):
        return self._crowd_info

    @crowd_info.setter
    def crowd_info(self, value):
        if isinstance(value, list):
            self._crowd_info = list()
            for i in value:
                if isinstance(i, ChannelPutPlanCrowdDTO):
                    self._crowd_info.append(i)
                else:
                    self._crowd_info.append(ChannelPutPlanCrowdDTO.from_alipay_dict(i))
    @property
    def customize_page(self):
        return self._customize_page

    @customize_page.setter
    def customize_page(self, value):
        self._customize_page = value
    @property
    def detail_page_title(self):
        return self._detail_page_title

    @detail_page_title.setter
    def detail_page_title(self, value):
        self._detail_page_title = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def gmt_plan_end(self):
        return self._gmt_plan_end

    @gmt_plan_end.setter
    def gmt_plan_end(self, value):
        self._gmt_plan_end = value
    @property
    def gmt_plan_start(self):
        return self._gmt_plan_start

    @gmt_plan_start.setter
    def gmt_plan_start(self, value):
        self._gmt_plan_start = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def modifier_id(self):
        return self._modifier_id

    @modifier_id.setter
    def modifier_id(self, value):
        self._modifier_id = value
    @property
    def modifier_name(self):
        return self._modifier_name

    @modifier_name.setter
    def modifier_name(self, value):
        self._modifier_name = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def page_type(self):
        return self._page_type

    @page_type.setter
    def page_type(self, value):
        self._page_type = value
    @property
    def pic_url(self):
        return self._pic_url

    @pic_url.setter
    def pic_url(self, value):
        self._pic_url = value
    @property
    def reject_reason(self):
        return self._reject_reason

    @reject_reason.setter
    def reject_reason(self, value):
        self._reject_reason = value
    @property
    def rule_text(self):
        return self._rule_text

    @rule_text.setter
    def rule_text(self, value):
        self._rule_text = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value
    @property
    def task_name(self):
        return self._task_name

    @task_name.setter
    def task_name(self, value):
        self._task_name = value
    @property
    def tenant_code(self):
        return self._tenant_code

    @tenant_code.setter
    def tenant_code(self, value):
        self._tenant_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_page:
            if hasattr(self.activity_page, 'to_alipay_dict'):
                params['activity_page'] = self.activity_page.to_alipay_dict()
            else:
                params['activity_page'] = self.activity_page
        if self.activity_page_name:
            if hasattr(self.activity_page_name, 'to_alipay_dict'):
                params['activity_page_name'] = self.activity_page_name.to_alipay_dict()
            else:
                params['activity_page_name'] = self.activity_page_name
        if self.activity_page_url:
            if hasattr(self.activity_page_url, 'to_alipay_dict'):
                params['activity_page_url'] = self.activity_page_url.to_alipay_dict()
            else:
                params['activity_page_url'] = self.activity_page_url
        if self.activity_title:
            if hasattr(self.activity_title, 'to_alipay_dict'):
                params['activity_title'] = self.activity_title.to_alipay_dict()
            else:
                params['activity_title'] = self.activity_title
        if self.benefit_desc:
            if hasattr(self.benefit_desc, 'to_alipay_dict'):
                params['benefit_desc'] = self.benefit_desc.to_alipay_dict()
            else:
                params['benefit_desc'] = self.benefit_desc
        if self.bill_way:
            if hasattr(self.bill_way, 'to_alipay_dict'):
                params['bill_way'] = self.bill_way.to_alipay_dict()
            else:
                params['bill_way'] = self.bill_way
        if self.channel_code:
            if hasattr(self.channel_code, 'to_alipay_dict'):
                params['channel_code'] = self.channel_code.to_alipay_dict()
            else:
                params['channel_code'] = self.channel_code
        if self.channel_id:
            if hasattr(self.channel_id, 'to_alipay_dict'):
                params['channel_id'] = self.channel_id.to_alipay_dict()
            else:
                params['channel_id'] = self.channel_id
        if self.channel_name:
            if hasattr(self.channel_name, 'to_alipay_dict'):
                params['channel_name'] = self.channel_name.to_alipay_dict()
            else:
                params['channel_name'] = self.channel_name
        if self.creator_id:
            if hasattr(self.creator_id, 'to_alipay_dict'):
                params['creator_id'] = self.creator_id.to_alipay_dict()
            else:
                params['creator_id'] = self.creator_id
        if self.creator_name:
            if hasattr(self.creator_name, 'to_alipay_dict'):
                params['creator_name'] = self.creator_name.to_alipay_dict()
            else:
                params['creator_name'] = self.creator_name
        if self.crowd_ids:
            if isinstance(self.crowd_ids, list):
                for i in range(0, len(self.crowd_ids)):
                    element = self.crowd_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.crowd_ids[i] = element.to_alipay_dict()
            if hasattr(self.crowd_ids, 'to_alipay_dict'):
                params['crowd_ids'] = self.crowd_ids.to_alipay_dict()
            else:
                params['crowd_ids'] = self.crowd_ids
        if self.crowd_info:
            if isinstance(self.crowd_info, list):
                for i in range(0, len(self.crowd_info)):
                    element = self.crowd_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.crowd_info[i] = element.to_alipay_dict()
            if hasattr(self.crowd_info, 'to_alipay_dict'):
                params['crowd_info'] = self.crowd_info.to_alipay_dict()
            else:
                params['crowd_info'] = self.crowd_info
        if self.customize_page:
            if hasattr(self.customize_page, 'to_alipay_dict'):
                params['customize_page'] = self.customize_page.to_alipay_dict()
            else:
                params['customize_page'] = self.customize_page
        if self.detail_page_title:
            if hasattr(self.detail_page_title, 'to_alipay_dict'):
                params['detail_page_title'] = self.detail_page_title.to_alipay_dict()
            else:
                params['detail_page_title'] = self.detail_page_title
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.gmt_plan_end:
            if hasattr(self.gmt_plan_end, 'to_alipay_dict'):
                params['gmt_plan_end'] = self.gmt_plan_end.to_alipay_dict()
            else:
                params['gmt_plan_end'] = self.gmt_plan_end
        if self.gmt_plan_start:
            if hasattr(self.gmt_plan_start, 'to_alipay_dict'):
                params['gmt_plan_start'] = self.gmt_plan_start.to_alipay_dict()
            else:
                params['gmt_plan_start'] = self.gmt_plan_start
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.modifier_id:
            if hasattr(self.modifier_id, 'to_alipay_dict'):
                params['modifier_id'] = self.modifier_id.to_alipay_dict()
            else:
                params['modifier_id'] = self.modifier_id
        if self.modifier_name:
            if hasattr(self.modifier_name, 'to_alipay_dict'):
                params['modifier_name'] = self.modifier_name.to_alipay_dict()
            else:
                params['modifier_name'] = self.modifier_name
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.page_type:
            if hasattr(self.page_type, 'to_alipay_dict'):
                params['page_type'] = self.page_type.to_alipay_dict()
            else:
                params['page_type'] = self.page_type
        if self.pic_url:
            if hasattr(self.pic_url, 'to_alipay_dict'):
                params['pic_url'] = self.pic_url.to_alipay_dict()
            else:
                params['pic_url'] = self.pic_url
        if self.reject_reason:
            if hasattr(self.reject_reason, 'to_alipay_dict'):
                params['reject_reason'] = self.reject_reason.to_alipay_dict()
            else:
                params['reject_reason'] = self.reject_reason
        if self.rule_text:
            if hasattr(self.rule_text, 'to_alipay_dict'):
                params['rule_text'] = self.rule_text.to_alipay_dict()
            else:
                params['rule_text'] = self.rule_text
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.task_id:
            if hasattr(self.task_id, 'to_alipay_dict'):
                params['task_id'] = self.task_id.to_alipay_dict()
            else:
                params['task_id'] = self.task_id
        if self.task_name:
            if hasattr(self.task_name, 'to_alipay_dict'):
                params['task_name'] = self.task_name.to_alipay_dict()
            else:
                params['task_name'] = self.task_name
        if self.tenant_code:
            if hasattr(self.tenant_code, 'to_alipay_dict'):
                params['tenant_code'] = self.tenant_code.to_alipay_dict()
            else:
                params['tenant_code'] = self.tenant_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ChannelPutPlanDetailDTO()
        if 'activity_page' in d:
            o.activity_page = d['activity_page']
        if 'activity_page_name' in d:
            o.activity_page_name = d['activity_page_name']
        if 'activity_page_url' in d:
            o.activity_page_url = d['activity_page_url']
        if 'activity_title' in d:
            o.activity_title = d['activity_title']
        if 'benefit_desc' in d:
            o.benefit_desc = d['benefit_desc']
        if 'bill_way' in d:
            o.bill_way = d['bill_way']
        if 'channel_code' in d:
            o.channel_code = d['channel_code']
        if 'channel_id' in d:
            o.channel_id = d['channel_id']
        if 'channel_name' in d:
            o.channel_name = d['channel_name']
        if 'creator_id' in d:
            o.creator_id = d['creator_id']
        if 'creator_name' in d:
            o.creator_name = d['creator_name']
        if 'crowd_ids' in d:
            o.crowd_ids = d['crowd_ids']
        if 'crowd_info' in d:
            o.crowd_info = d['crowd_info']
        if 'customize_page' in d:
            o.customize_page = d['customize_page']
        if 'detail_page_title' in d:
            o.detail_page_title = d['detail_page_title']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'gmt_plan_end' in d:
            o.gmt_plan_end = d['gmt_plan_end']
        if 'gmt_plan_start' in d:
            o.gmt_plan_start = d['gmt_plan_start']
        if 'id' in d:
            o.id = d['id']
        if 'modifier_id' in d:
            o.modifier_id = d['modifier_id']
        if 'modifier_name' in d:
            o.modifier_name = d['modifier_name']
        if 'name' in d:
            o.name = d['name']
        if 'page_type' in d:
            o.page_type = d['page_type']
        if 'pic_url' in d:
            o.pic_url = d['pic_url']
        if 'reject_reason' in d:
            o.reject_reason = d['reject_reason']
        if 'rule_text' in d:
            o.rule_text = d['rule_text']
        if 'status' in d:
            o.status = d['status']
        if 'task_id' in d:
            o.task_id = d['task_id']
        if 'task_name' in d:
            o.task_name = d['task_name']
        if 'tenant_code' in d:
            o.tenant_code = d['tenant_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ArrangementBaseSelector import ArrangementBaseSelector
from alipay.aop.api.domain.ArrangementConditionGroupSelector import ArrangementConditionGroupSelector
from alipay.aop.api.domain.ArrangementInvolvedPartyQuerier import ArrangementInvolvedPartyQuerier
from alipay.aop.api.domain.ArrangementNoQuerier import ArrangementNoQuerier


class AntProdpaasArrangementCommonQueryModel(object):

    def __init__(self):
        self._arrangement_base_selector = None
        self._arrangement_condition_group_selector = None
        self._arrangement_involved_party_querier = None
        self._arrangement_no_querier = None

    @property
    def arrangement_base_selector(self):
        return self._arrangement_base_selector

    @arrangement_base_selector.setter
    def arrangement_base_selector(self, value):
        if isinstance(value, ArrangementBaseSelector):
            self._arrangement_base_selector = value
        else:
            self._arrangement_base_selector = ArrangementBaseSelector.from_alipay_dict(value)
    @property
    def arrangement_condition_group_selector(self):
        return self._arrangement_condition_group_selector

    @arrangement_condition_group_selector.setter
    def arrangement_condition_group_selector(self, value):
        if isinstance(value, ArrangementConditionGroupSelector):
            self._arrangement_condition_group_selector = value
        else:
            self._arrangement_condition_group_selector = ArrangementConditionGroupSelector.from_alipay_dict(value)
    @property
    def arrangement_involved_party_querier(self):
        return self._arrangement_involved_party_querier

    @arrangement_involved_party_querier.setter
    def arrangement_involved_party_querier(self, value):
        if isinstance(value, ArrangementInvolvedPartyQuerier):
            self._arrangement_involved_party_querier = value
        else:
            self._arrangement_involved_party_querier = ArrangementInvolvedPartyQuerier.from_alipay_dict(value)
    @property
    def arrangement_no_querier(self):
        return self._arrangement_no_querier

    @arrangement_no_querier.setter
    def arrangement_no_querier(self, value):
        if isinstance(value, ArrangementNoQuerier):
            self._arrangement_no_querier = value
        else:
            self._arrangement_no_querier = ArrangementNoQuerier.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.arrangement_base_selector:
            if hasattr(self.arrangement_base_selector, 'to_alipay_dict'):
                params['arrangement_base_selector'] = self.arrangement_base_selector.to_alipay_dict()
            else:
                params['arrangement_base_selector'] = self.arrangement_base_selector
        if self.arrangement_condition_group_selector:
            if hasattr(self.arrangement_condition_group_selector, 'to_alipay_dict'):
                params['arrangement_condition_group_selector'] = self.arrangement_condition_group_selector.to_alipay_dict()
            else:
                params['arrangement_condition_group_selector'] = self.arrangement_condition_group_selector
        if self.arrangement_involved_party_querier:
            if hasattr(self.arrangement_involved_party_querier, 'to_alipay_dict'):
                params['arrangement_involved_party_querier'] = self.arrangement_involved_party_querier.to_alipay_dict()
            else:
                params['arrangement_involved_party_querier'] = self.arrangement_involved_party_querier
        if self.arrangement_no_querier:
            if hasattr(self.arrangement_no_querier, 'to_alipay_dict'):
                params['arrangement_no_querier'] = self.arrangement_no_querier.to_alipay_dict()
            else:
                params['arrangement_no_querier'] = self.arrangement_no_querier
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntProdpaasArrangementCommonQueryModel()
        if 'arrangement_base_selector' in d:
            o.arrangement_base_selector = d['arrangement_base_selector']
        if 'arrangement_condition_group_selector' in d:
            o.arrangement_condition_group_selector = d['arrangement_condition_group_selector']
        if 'arrangement_involved_party_querier' in d:
            o.arrangement_involved_party_querier = d['arrangement_involved_party_querier']
        if 'arrangement_no_querier' in d:
            o.arrangement_no_querier = d['arrangement_no_querier']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenMiniDataSummaryQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniDataSummaryQueryResponse, self).__init__()
        self._app_pv = None
        self._app_uv = None
        self._avg_stay_time_per_user = None
        self._avg_stay_time_per_visit = None
        self._launch_cnt = None
        self._launch_cnt_dst = None
        self._new_user_cnt = None
        self._share_cnt = None
        self._share_cnt_dst = None
        self._share_user_cnt = None
        self._share_user_cnt_dst = None
        self._user_cnt_30_d = None
        self._user_cnt_7_d = None
        self._user_cnt_dst = None

    @property
    def app_pv(self):
        return self._app_pv

    @app_pv.setter
    def app_pv(self, value):
        self._app_pv = value
    @property
    def app_uv(self):
        return self._app_uv

    @app_uv.setter
    def app_uv(self, value):
        self._app_uv = value
    @property
    def avg_stay_time_per_user(self):
        return self._avg_stay_time_per_user

    @avg_stay_time_per_user.setter
    def avg_stay_time_per_user(self, value):
        self._avg_stay_time_per_user = value
    @property
    def avg_stay_time_per_visit(self):
        return self._avg_stay_time_per_visit

    @avg_stay_time_per_visit.setter
    def avg_stay_time_per_visit(self, value):
        self._avg_stay_time_per_visit = value
    @property
    def launch_cnt(self):
        return self._launch_cnt

    @launch_cnt.setter
    def launch_cnt(self, value):
        self._launch_cnt = value
    @property
    def launch_cnt_dst(self):
        return self._launch_cnt_dst

    @launch_cnt_dst.setter
    def launch_cnt_dst(self, value):
        self._launch_cnt_dst = value
    @property
    def new_user_cnt(self):
        return self._new_user_cnt

    @new_user_cnt.setter
    def new_user_cnt(self, value):
        self._new_user_cnt = value
    @property
    def share_cnt(self):
        return self._share_cnt

    @share_cnt.setter
    def share_cnt(self, value):
        self._share_cnt = value
    @property
    def share_cnt_dst(self):
        return self._share_cnt_dst

    @share_cnt_dst.setter
    def share_cnt_dst(self, value):
        self._share_cnt_dst = value
    @property
    def share_user_cnt(self):
        return self._share_user_cnt

    @share_user_cnt.setter
    def share_user_cnt(self, value):
        self._share_user_cnt = value
    @property
    def share_user_cnt_dst(self):
        return self._share_user_cnt_dst

    @share_user_cnt_dst.setter
    def share_user_cnt_dst(self, value):
        self._share_user_cnt_dst = value
    @property
    def user_cnt_30_d(self):
        return self._user_cnt_30_d

    @user_cnt_30_d.setter
    def user_cnt_30_d(self, value):
        self._user_cnt_30_d = value
    @property
    def user_cnt_7_d(self):
        return self._user_cnt_7_d

    @user_cnt_7_d.setter
    def user_cnt_7_d(self, value):
        self._user_cnt_7_d = value
    @property
    def user_cnt_dst(self):
        return self._user_cnt_dst

    @user_cnt_dst.setter
    def user_cnt_dst(self, value):
        self._user_cnt_dst = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniDataSummaryQueryResponse, self).parse_response_content(response_content)
        if 'app_pv' in response:
            self.app_pv = response['app_pv']
        if 'app_uv' in response:
            self.app_uv = response['app_uv']
        if 'avg_stay_time_per_user' in response:
            self.avg_stay_time_per_user = response['avg_stay_time_per_user']
        if 'avg_stay_time_per_visit' in response:
            self.avg_stay_time_per_visit = response['avg_stay_time_per_visit']
        if 'launch_cnt' in response:
            self.launch_cnt = response['launch_cnt']
        if 'launch_cnt_dst' in response:
            self.launch_cnt_dst = response['launch_cnt_dst']
        if 'new_user_cnt' in response:
            self.new_user_cnt = response['new_user_cnt']
        if 'share_cnt' in response:
            self.share_cnt = response['share_cnt']
        if 'share_cnt_dst' in response:
            self.share_cnt_dst = response['share_cnt_dst']
        if 'share_user_cnt' in response:
            self.share_user_cnt = response['share_user_cnt']
        if 'share_user_cnt_dst' in response:
            self.share_user_cnt_dst = response['share_user_cnt_dst']
        if 'user_cnt_30_d' in response:
            self.user_cnt_30_d = response['user_cnt_30_d']
        if 'user_cnt_7_d' in response:
            self.user_cnt_7_d = response['user_cnt_7_d']
        if 'user_cnt_dst' in response:
            self.user_cnt_dst = response['user_cnt_dst']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppInvoiceExpensecontrolIssuebatchCancelResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppInvoiceExpensecontrolIssuebatchCancelResponse, self).__init__()
        self._result = None

    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, value):
        self._result = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppInvoiceExpensecontrolIssuebatchCancelResponse, self).parse_response_content(response_content)
        if 'result' in response:
            self.result = response['result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntProdpaasArrangementRebateRateQueryModel(object):

    def __init__(self):
        self._data_item_name = None
        self._first_category_id = None
        self._gmt_query = None

    @property
    def data_item_name(self):
        return self._data_item_name

    @data_item_name.setter
    def data_item_name(self, value):
        self._data_item_name = value
    @property
    def first_category_id(self):
        return self._first_category_id

    @first_category_id.setter
    def first_category_id(self, value):
        self._first_category_id = value
    @property
    def gmt_query(self):
        return self._gmt_query

    @gmt_query.setter
    def gmt_query(self, value):
        self._gmt_query = value


    def to_alipay_dict(self):
        params = dict()
        if self.data_item_name:
            if hasattr(self.data_item_name, 'to_alipay_dict'):
                params['data_item_name'] = self.data_item_name.to_alipay_dict()
            else:
                params['data_item_name'] = self.data_item_name
        if self.first_category_id:
            if hasattr(self.first_category_id, 'to_alipay_dict'):
                params['first_category_id'] = self.first_category_id.to_alipay_dict()
            else:
                params['first_category_id'] = self.first_category_id
        if self.gmt_query:
            if hasattr(self.gmt_query, 'to_alipay_dict'):
                params['gmt_query'] = self.gmt_query.to_alipay_dict()
            else:
                params['gmt_query'] = self.gmt_query
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntProdpaasArrangementRebateRateQueryModel()
        if 'data_item_name' in d:
            o.data_item_name = d['data_item_name']
        if 'first_category_id' in d:
            o.first_category_id = d['first_category_id']
        if 'gmt_query' in d:
            o.gmt_query = d['gmt_query']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserDtbankQrcodedataQueryModel(object):

    def __init__(self):
        self._data_date = None
        self._qrcode_id = None
        self._qrcode_out_id = None

    @property
    def data_date(self):
        return self._data_date

    @data_date.setter
    def data_date(self, value):
        self._data_date = value
    @property
    def qrcode_id(self):
        return self._qrcode_id

    @qrcode_id.setter
    def qrcode_id(self, value):
        self._qrcode_id = value
    @property
    def qrcode_out_id(self):
        return self._qrcode_out_id

    @qrcode_out_id.setter
    def qrcode_out_id(self, value):
        self._qrcode_out_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.data_date:
            if hasattr(self.data_date, 'to_alipay_dict'):
                params['data_date'] = self.data_date.to_alipay_dict()
            else:
                params['data_date'] = self.data_date
        if self.qrcode_id:
            if hasattr(self.qrcode_id, 'to_alipay_dict'):
                params['qrcode_id'] = self.qrcode_id.to_alipay_dict()
            else:
                params['qrcode_id'] = self.qrcode_id
        if self.qrcode_out_id:
            if hasattr(self.qrcode_out_id, 'to_alipay_dict'):
                params['qrcode_out_id'] = self.qrcode_out_id.to_alipay_dict()
            else:
                params['qrcode_out_id'] = self.qrcode_out_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserDtbankQrcodedataQueryModel()
        if 'data_date' in d:
            o.data_date = d['data_date']
        if 'qrcode_id' in d:
            o.qrcode_id = d['qrcode_id']
        if 'qrcode_out_id' in d:
            o.qrcode_out_id = d['qrcode_out_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechBlockchainFinanceAssetmanagePenetratebillQueryModel(object):

    def __init__(self):
        self._agreement_code = None
        self._bill_date = None
        self._bill_period = None

    @property
    def agreement_code(self):
        return self._agreement_code

    @agreement_code.setter
    def agreement_code(self, value):
        self._agreement_code = value
    @property
    def bill_date(self):
        return self._bill_date

    @bill_date.setter
    def bill_date(self, value):
        self._bill_date = value
    @property
    def bill_period(self):
        return self._bill_period

    @bill_period.setter
    def bill_period(self, value):
        self._bill_period = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_code:
            if hasattr(self.agreement_code, 'to_alipay_dict'):
                params['agreement_code'] = self.agreement_code.to_alipay_dict()
            else:
                params['agreement_code'] = self.agreement_code
        if self.bill_date:
            if hasattr(self.bill_date, 'to_alipay_dict'):
                params['bill_date'] = self.bill_date.to_alipay_dict()
            else:
                params['bill_date'] = self.bill_date
        if self.bill_period:
            if hasattr(self.bill_period, 'to_alipay_dict'):
                params['bill_period'] = self.bill_period.to_alipay_dict()
            else:
                params['bill_period'] = self.bill_period
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainFinanceAssetmanagePenetratebillQueryModel()
        if 'agreement_code' in d:
            o.agreement_code = d['agreement_code']
        if 'bill_date' in d:
            o.bill_date = d['bill_date']
        if 'bill_period' in d:
            o.bill_period = d['bill_period']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenAppServicePromoDeleteResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppServicePromoDeleteResponse, self).__init__()
        self._promo_record_id = None

    @property
    def promo_record_id(self):
        return self._promo_record_id

    @promo_record_id.setter
    def promo_record_id(self, value):
        self._promo_record_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppServicePromoDeleteResponse, self).parse_response_content(response_content)
        if 'promo_record_id' in response:
            self.promo_record_id = response['promo_record_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataSsssxxxTransferModel(object):

    def __init__(self):
        self._ddd = None

    @property
    def ddd(self):
        return self._ddd

    @ddd.setter
    def ddd(self, value):
        self._ddd = value


    def to_alipay_dict(self):
        params = dict()
        if self.ddd:
            if hasattr(self.ddd, 'to_alipay_dict'):
                params['ddd'] = self.ddd.to_alipay_dict()
            else:
                params['ddd'] = self.ddd
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataSsssxxxTransferModel()
        if 'ddd' in d:
            o.ddd = d['ddd']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ReceiverInfoVO import ReceiverInfoVO
from alipay.aop.api.domain.SenderInfoVO import SenderInfoVO


class OutboundOrder(object):

    def __init__(self):
        self._ext_info = None
        self._out_biz_no = None
        self._outbound_type = None
        self._receiver_info_vo = None
        self._remark = None
        self._sender_info_vo = None
        self._warehouse_code = None

    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def outbound_type(self):
        return self._outbound_type

    @outbound_type.setter
    def outbound_type(self, value):
        self._outbound_type = value
    @property
    def receiver_info_vo(self):
        return self._receiver_info_vo

    @receiver_info_vo.setter
    def receiver_info_vo(self, value):
        if isinstance(value, ReceiverInfoVO):
            self._receiver_info_vo = value
        else:
            self._receiver_info_vo = ReceiverInfoVO.from_alipay_dict(value)
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def sender_info_vo(self):
        return self._sender_info_vo

    @sender_info_vo.setter
    def sender_info_vo(self, value):
        if isinstance(value, SenderInfoVO):
            self._sender_info_vo = value
        else:
            self._sender_info_vo = SenderInfoVO.from_alipay_dict(value)
    @property
    def warehouse_code(self):
        return self._warehouse_code

    @warehouse_code.setter
    def warehouse_code(self, value):
        self._warehouse_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.outbound_type:
            if hasattr(self.outbound_type, 'to_alipay_dict'):
                params['outbound_type'] = self.outbound_type.to_alipay_dict()
            else:
                params['outbound_type'] = self.outbound_type
        if self.receiver_info_vo:
            if hasattr(self.receiver_info_vo, 'to_alipay_dict'):
                params['receiver_info_vo'] = self.receiver_info_vo.to_alipay_dict()
            else:
                params['receiver_info_vo'] = self.receiver_info_vo
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.sender_info_vo:
            if hasattr(self.sender_info_vo, 'to_alipay_dict'):
                params['sender_info_vo'] = self.sender_info_vo.to_alipay_dict()
            else:
                params['sender_info_vo'] = self.sender_info_vo
        if self.warehouse_code:
            if hasattr(self.warehouse_code, 'to_alipay_dict'):
                params['warehouse_code'] = self.warehouse_code.to_alipay_dict()
            else:
                params['warehouse_code'] = self.warehouse_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OutboundOrder()
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'outbound_type' in d:
            o.outbound_type = d['outbound_type']
        if 'receiver_info_vo' in d:
            o.receiver_info_vo = d['receiver_info_vo']
        if 'remark' in d:
            o.remark = d['remark']
        if 'sender_info_vo' in d:
            o.sender_info_vo = d['sender_info_vo']
        if 'warehouse_code' in d:
            o.warehouse_code = d['warehouse_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SettleExtendParams(object):

    def __init__(self):
        self._royalty_finish = None

    @property
    def royalty_finish(self):
        return self._royalty_finish

    @royalty_finish.setter
    def royalty_finish(self, value):
        self._royalty_finish = value


    def to_alipay_dict(self):
        params = dict()
        if self.royalty_finish:
            if hasattr(self.royalty_finish, 'to_alipay_dict'):
                params['royalty_finish'] = self.royalty_finish.to_alipay_dict()
            else:
                params['royalty_finish'] = self.royalty_finish
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SettleExtendParams()
        if 'royalty_finish' in d:
            o.royalty_finish = d['royalty_finish']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntfortuneContentCommunityDataSendModel(object):

    def __init__(self):
        self._content = None
        self._source_id = None
        self._soure_type = None

    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def source_id(self):
        return self._source_id

    @source_id.setter
    def source_id(self, value):
        self._source_id = value
    @property
    def soure_type(self):
        return self._soure_type

    @soure_type.setter
    def soure_type(self, value):
        self._soure_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.source_id:
            if hasattr(self.source_id, 'to_alipay_dict'):
                params['source_id'] = self.source_id.to_alipay_dict()
            else:
                params['source_id'] = self.source_id
        if self.soure_type:
            if hasattr(self.soure_type, 'to_alipay_dict'):
                params['soure_type'] = self.soure_type.to_alipay_dict()
            else:
                params['soure_type'] = self.soure_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntfortuneContentCommunityDataSendModel()
        if 'content' in d:
            o.content = d['content']
        if 'source_id' in d:
            o.source_id = d['source_id']
        if 'soure_type' in d:
            o.soure_type = d['soure_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppInvoiceEnterpriseMerchantrelationCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppInvoiceEnterpriseMerchantrelationCreateResponse, self).__init__()
        self._pid = None
        self._role_type = None
        self._shop_id = None
        self._success = None

    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def role_type(self):
        return self._role_type

    @role_type.setter
    def role_type(self, value):
        self._role_type = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppInvoiceEnterpriseMerchantrelationCreateResponse, self).parse_response_content(response_content)
        if 'pid' in response:
            self.pid = response['pid']
        if 'role_type' in response:
            self.role_type = response['role_type']
        if 'shop_id' in response:
            self.shop_id = response['shop_id']
        if 'success' in response:
            self.success = response['success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RiskInfoDetail(object):

    def __init__(self):
        self._dialog_index = None
        self._hit_word = None
        self._hit_word_index = None
        self._hit_word_type = None
        self._new_picture_frame = None
        self._picture_frame = None

    @property
    def dialog_index(self):
        return self._dialog_index

    @dialog_index.setter
    def dialog_index(self, value):
        self._dialog_index = value
    @property
    def hit_word(self):
        return self._hit_word

    @hit_word.setter
    def hit_word(self, value):
        self._hit_word = value
    @property
    def hit_word_index(self):
        return self._hit_word_index

    @hit_word_index.setter
    def hit_word_index(self, value):
        self._hit_word_index = value
    @property
    def hit_word_type(self):
        return self._hit_word_type

    @hit_word_type.setter
    def hit_word_type(self, value):
        self._hit_word_type = value
    @property
    def new_picture_frame(self):
        return self._new_picture_frame

    @new_picture_frame.setter
    def new_picture_frame(self, value):
        self._new_picture_frame = value
    @property
    def picture_frame(self):
        return self._picture_frame

    @picture_frame.setter
    def picture_frame(self, value):
        self._picture_frame = value


    def to_alipay_dict(self):
        params = dict()
        if self.dialog_index:
            if hasattr(self.dialog_index, 'to_alipay_dict'):
                params['dialog_index'] = self.dialog_index.to_alipay_dict()
            else:
                params['dialog_index'] = self.dialog_index
        if self.hit_word:
            if hasattr(self.hit_word, 'to_alipay_dict'):
                params['hit_word'] = self.hit_word.to_alipay_dict()
            else:
                params['hit_word'] = self.hit_word
        if self.hit_word_index:
            if hasattr(self.hit_word_index, 'to_alipay_dict'):
                params['hit_word_index'] = self.hit_word_index.to_alipay_dict()
            else:
                params['hit_word_index'] = self.hit_word_index
        if self.hit_word_type:
            if hasattr(self.hit_word_type, 'to_alipay_dict'):
                params['hit_word_type'] = self.hit_word_type.to_alipay_dict()
            else:
                params['hit_word_type'] = self.hit_word_type
        if self.new_picture_frame:
            if hasattr(self.new_picture_frame, 'to_alipay_dict'):
                params['new_picture_frame'] = self.new_picture_frame.to_alipay_dict()
            else:
                params['new_picture_frame'] = self.new_picture_frame
        if self.picture_frame:
            if hasattr(self.picture_frame, 'to_alipay_dict'):
                params['picture_frame'] = self.picture_frame.to_alipay_dict()
            else:
                params['picture_frame'] = self.picture_frame
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RiskInfoDetail()
        if 'dialog_index' in d:
            o.dialog_index = d['dialog_index']
        if 'hit_word' in d:
            o.hit_word = d['hit_word']
        if 'hit_word_index' in d:
            o.hit_word_index = d['hit_word_index']
        if 'hit_word_type' in d:
            o.hit_word_type = d['hit_word_type']
        if 'new_picture_frame' in d:
            o.new_picture_frame = d['new_picture_frame']
        if 'picture_frame' in d:
            o.picture_frame = d['picture_frame']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AppItemAttrVO(object):

    def __init__(self):
        self._attr_key = None
        self._attr_value = None

    @property
    def attr_key(self):
        return self._attr_key

    @attr_key.setter
    def attr_key(self, value):
        self._attr_key = value
    @property
    def attr_value(self):
        return self._attr_value

    @attr_value.setter
    def attr_value(self, value):
        self._attr_value = value


    def to_alipay_dict(self):
        params = dict()
        if self.attr_key:
            if hasattr(self.attr_key, 'to_alipay_dict'):
                params['attr_key'] = self.attr_key.to_alipay_dict()
            else:
                params['attr_key'] = self.attr_key
        if self.attr_value:
            if hasattr(self.attr_value, 'to_alipay_dict'):
                params['attr_value'] = self.attr_value.to_alipay_dict()
            else:
                params['attr_value'] = self.attr_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AppItemAttrVO()
        if 'attr_key' in d:
            o.attr_key = d['attr_key']
        if 'attr_value' in d:
            o.attr_value = d['attr_value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEcEnterpriseInfoModifyModel(object):

    def __init__(self):
        self._enterprise_alias = None
        self._enterprise_id = None
        self._enterprise_name = None

    @property
    def enterprise_alias(self):
        return self._enterprise_alias

    @enterprise_alias.setter
    def enterprise_alias(self, value):
        self._enterprise_alias = value
    @property
    def enterprise_id(self):
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        self._enterprise_id = value
    @property
    def enterprise_name(self):
        return self._enterprise_name

    @enterprise_name.setter
    def enterprise_name(self, value):
        self._enterprise_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.enterprise_alias:
            if hasattr(self.enterprise_alias, 'to_alipay_dict'):
                params['enterprise_alias'] = self.enterprise_alias.to_alipay_dict()
            else:
                params['enterprise_alias'] = self.enterprise_alias
        if self.enterprise_id:
            if hasattr(self.enterprise_id, 'to_alipay_dict'):
                params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
            else:
                params['enterprise_id'] = self.enterprise_id
        if self.enterprise_name:
            if hasattr(self.enterprise_name, 'to_alipay_dict'):
                params['enterprise_name'] = self.enterprise_name.to_alipay_dict()
            else:
                params['enterprise_name'] = self.enterprise_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEcEnterpriseInfoModifyModel()
        if 'enterprise_alias' in d:
            o.enterprise_alias = d['enterprise_alias']
        if 'enterprise_id' in d:
            o.enterprise_id = d['enterprise_id']
        if 'enterprise_name' in d:
            o.enterprise_name = d['enterprise_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingCampaignUnitedopencouponReceiveTriggerModel(object):

    def __init__(self):
        self._bind_mobile = None
        self._camp_id = None
        self._channel_info = None
        self._client_ip = None
        self._login_id = None
        self._open_id = None
        self._out_biz_no = None
        self._term_id = None
        self._user_id = None

    @property
    def bind_mobile(self):
        return self._bind_mobile

    @bind_mobile.setter
    def bind_mobile(self, value):
        self._bind_mobile = value
    @property
    def camp_id(self):
        return self._camp_id

    @camp_id.setter
    def camp_id(self, value):
        self._camp_id = value
    @property
    def channel_info(self):
        return self._channel_info

    @channel_info.setter
    def channel_info(self, value):
        self._channel_info = value
    @property
    def client_ip(self):
        return self._client_ip

    @client_ip.setter
    def client_ip(self, value):
        self._client_ip = value
    @property
    def login_id(self):
        return self._login_id

    @login_id.setter
    def login_id(self, value):
        self._login_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def term_id(self):
        return self._term_id

    @term_id.setter
    def term_id(self, value):
        self._term_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.bind_mobile:
            if hasattr(self.bind_mobile, 'to_alipay_dict'):
                params['bind_mobile'] = self.bind_mobile.to_alipay_dict()
            else:
                params['bind_mobile'] = self.bind_mobile
        if self.camp_id:
            if hasattr(self.camp_id, 'to_alipay_dict'):
                params['camp_id'] = self.camp_id.to_alipay_dict()
            else:
                params['camp_id'] = self.camp_id
        if self.channel_info:
            if hasattr(self.channel_info, 'to_alipay_dict'):
                params['channel_info'] = self.channel_info.to_alipay_dict()
            else:
                params['channel_info'] = self.channel_info
        if self.client_ip:
            if hasattr(self.client_ip, 'to_alipay_dict'):
                params['client_ip'] = self.client_ip.to_alipay_dict()
            else:
                params['client_ip'] = self.client_ip
        if self.login_id:
            if hasattr(self.login_id, 'to_alipay_dict'):
                params['login_id'] = self.login_id.to_alipay_dict()
            else:
                params['login_id'] = self.login_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.term_id:
            if hasattr(self.term_id, 'to_alipay_dict'):
                params['term_id'] = self.term_id.to_alipay_dict()
            else:
                params['term_id'] = self.term_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCampaignUnitedopencouponReceiveTriggerModel()
        if 'bind_mobile' in d:
            o.bind_mobile = d['bind_mobile']
        if 'camp_id' in d:
            o.camp_id = d['camp_id']
        if 'channel_info' in d:
            o.channel_info = d['channel_info']
        if 'client_ip' in d:
            o.client_ip = d['client_ip']
        if 'login_id' in d:
            o.login_id = d['login_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'term_id' in d:
            o.term_id = d['term_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcoCityserviceExtOrdercompleteQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoCityserviceExtOrdercompleteQueryResponse, self).__init__()
        self._order_complete_status = None
        self._out_request_no = None
        self._out_trade_no = None

    @property
    def order_complete_status(self):
        return self._order_complete_status

    @order_complete_status.setter
    def order_complete_status(self, value):
        self._order_complete_status = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoCityserviceExtOrdercompleteQueryResponse, self).parse_response_content(response_content)
        if 'order_complete_status' in response:
            self.order_complete_status = response['order_complete_status']
        if 'out_request_no' in response:
            self.out_request_no = response['out_request_no']
        if 'out_trade_no' in response:
            self.out_trade_no = response['out_trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Article import Article
from alipay.aop.api.domain.Text import Text


class AlipayOpenPublicMessageTotalSendModel(object):

    def __init__(self):
        self._articles = None
        self._msg_type = None
        self._text = None

    @property
    def articles(self):
        return self._articles

    @articles.setter
    def articles(self, value):
        if isinstance(value, list):
            self._articles = list()
            for i in value:
                if isinstance(i, Article):
                    self._articles.append(i)
                else:
                    self._articles.append(Article.from_alipay_dict(i))
    @property
    def msg_type(self):
        return self._msg_type

    @msg_type.setter
    def msg_type(self, value):
        self._msg_type = value
    @property
    def text(self):
        return self._text

    @text.setter
    def text(self, value):
        if isinstance(value, Text):
            self._text = value
        else:
            self._text = Text.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.articles:
            if isinstance(self.articles, list):
                for i in range(0, len(self.articles)):
                    element = self.articles[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.articles[i] = element.to_alipay_dict()
            if hasattr(self.articles, 'to_alipay_dict'):
                params['articles'] = self.articles.to_alipay_dict()
            else:
                params['articles'] = self.articles
        if self.msg_type:
            if hasattr(self.msg_type, 'to_alipay_dict'):
                params['msg_type'] = self.msg_type.to_alipay_dict()
            else:
                params['msg_type'] = self.msg_type
        if self.text:
            if hasattr(self.text, 'to_alipay_dict'):
                params['text'] = self.text.to_alipay_dict()
            else:
                params['text'] = self.text
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenPublicMessageTotalSendModel()
        if 'articles' in d:
            o.articles = d['articles']
        if 'msg_type' in d:
            o.msg_type = d['msg_type']
        if 'text' in d:
            o.text = d['text']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDigitalopUcdpApeexperimentQueryModel(object):

    def __init__(self):
        self._end_date = None
        self._project_id = None
        self._start_date = None

    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def project_id(self):
        return self._project_id

    @project_id.setter
    def project_id(self, value):
        self._project_id = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.project_id:
            if hasattr(self.project_id, 'to_alipay_dict'):
                params['project_id'] = self.project_id.to_alipay_dict()
            else:
                params['project_id'] = self.project_id
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDigitalopUcdpApeexperimentQueryModel()
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'project_id' in d:
            o.project_id = d['project_id']
        if 'start_date' in d:
            o.start_date = d['start_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.TicketDetailInfo import TicketDetailInfo


class AlipayCommerceCityfacilitatorVoucherBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceCityfacilitatorVoucherBatchqueryResponse, self).__init__()
        self._tickets = None

    @property
    def tickets(self):
        return self._tickets

    @tickets.setter
    def tickets(self, value):
        if isinstance(value, list):
            self._tickets = list()
            for i in value:
                if isinstance(i, TicketDetailInfo):
                    self._tickets.append(i)
                else:
                    self._tickets.append(TicketDetailInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceCityfacilitatorVoucherBatchqueryResponse, self).parse_response_content(response_content)
        if 'tickets' in response:
            self.tickets = response['tickets']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ChatMessage import ChatMessage


class AlipayIserviceCcmOlsChatrecordQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayIserviceCcmOlsChatrecordQueryResponse, self).__init__()
        self._agent_id = None
        self._agent_name = None
        self._categories = None
        self._group_id = None
        self._group_name = None
        self._memo = None
        self._messages = None
        self._satisfaction = None
        self._status = None
        self._talk_duration = None
        self._visitor_province = None

    @property
    def agent_id(self):
        return self._agent_id

    @agent_id.setter
    def agent_id(self, value):
        self._agent_id = value
    @property
    def agent_name(self):
        return self._agent_name

    @agent_name.setter
    def agent_name(self, value):
        self._agent_name = value
    @property
    def categories(self):
        return self._categories

    @categories.setter
    def categories(self, value):
        self._categories = value
    @property
    def group_id(self):
        return self._group_id

    @group_id.setter
    def group_id(self, value):
        self._group_id = value
    @property
    def group_name(self):
        return self._group_name

    @group_name.setter
    def group_name(self, value):
        self._group_name = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def messages(self):
        return self._messages

    @messages.setter
    def messages(self, value):
        if isinstance(value, list):
            self._messages = list()
            for i in value:
                if isinstance(i, ChatMessage):
                    self._messages.append(i)
                else:
                    self._messages.append(ChatMessage.from_alipay_dict(i))
    @property
    def satisfaction(self):
        return self._satisfaction

    @satisfaction.setter
    def satisfaction(self, value):
        self._satisfaction = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def talk_duration(self):
        return self._talk_duration

    @talk_duration.setter
    def talk_duration(self, value):
        self._talk_duration = value
    @property
    def visitor_province(self):
        return self._visitor_province

    @visitor_province.setter
    def visitor_province(self, value):
        self._visitor_province = value

    def parse_response_content(self, response_content):
        response = super(AlipayIserviceCcmOlsChatrecordQueryResponse, self).parse_response_content(response_content)
        if 'agent_id' in response:
            self.agent_id = response['agent_id']
        if 'agent_name' in response:
            self.agent_name = response['agent_name']
        if 'categories' in response:
            self.categories = response['categories']
        if 'group_id' in response:
            self.group_id = response['group_id']
        if 'group_name' in response:
            self.group_name = response['group_name']
        if 'memo' in response:
            self.memo = response['memo']
        if 'messages' in response:
            self.messages = response['messages']
        if 'satisfaction' in response:
            self.satisfaction = response['satisfaction']
        if 'status' in response:
            self.status = response['status']
        if 'talk_duration' in response:
            self.talk_duration = response['talk_duration']
        if 'visitor_province' in response:
            self.visitor_province = response['visitor_province']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GavintestNewLeveaOne(object):

    def __init__(self):
        self._boolen = None
        self._ces = None
        self._des = None
        self._str = None

    @property
    def boolen(self):
        return self._boolen

    @boolen.setter
    def boolen(self, value):
        self._boolen = value
    @property
    def ces(self):
        return self._ces

    @ces.setter
    def ces(self, value):
        if isinstance(value, list):
            self._ces = list()
            for i in value:
                self._ces.append(i)
    @property
    def des(self):
        return self._des

    @des.setter
    def des(self, value):
        self._des = value
    @property
    def str(self):
        return self._str

    @str.setter
    def str(self, value):
        if isinstance(value, list):
            self._str = list()
            for i in value:
                self._str.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.boolen:
            if hasattr(self.boolen, 'to_alipay_dict'):
                params['boolen'] = self.boolen.to_alipay_dict()
            else:
                params['boolen'] = self.boolen
        if self.ces:
            if isinstance(self.ces, list):
                for i in range(0, len(self.ces)):
                    element = self.ces[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ces[i] = element.to_alipay_dict()
            if hasattr(self.ces, 'to_alipay_dict'):
                params['ces'] = self.ces.to_alipay_dict()
            else:
                params['ces'] = self.ces
        if self.des:
            if hasattr(self.des, 'to_alipay_dict'):
                params['des'] = self.des.to_alipay_dict()
            else:
                params['des'] = self.des
        if self.str:
            if isinstance(self.str, list):
                for i in range(0, len(self.str)):
                    element = self.str[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.str[i] = element.to_alipay_dict()
            if hasattr(self.str, 'to_alipay_dict'):
                params['str'] = self.str.to_alipay_dict()
            else:
                params['str'] = self.str
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GavintestNewLeveaOne()
        if 'boolen' in d:
            o.boolen = d['boolen']
        if 'ces' in d:
            o.ces = d['ces']
        if 'des' in d:
            o.des = d['des']
        if 'str' in d:
            o.str = d['str']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMarketingAdvertisingModifyModel(object):

    def __init__(self):
        self._action_url = None
        self._ad_id = None
        self._content = None
        self._end_time = None
        self._height = None
        self._start_time = None

    @property
    def action_url(self):
        return self._action_url

    @action_url.setter
    def action_url(self, value):
        self._action_url = value
    @property
    def ad_id(self):
        return self._ad_id

    @ad_id.setter
    def ad_id(self, value):
        self._ad_id = value
    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def height(self):
        return self._height

    @height.setter
    def height(self, value):
        self._height = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_url:
            if hasattr(self.action_url, 'to_alipay_dict'):
                params['action_url'] = self.action_url.to_alipay_dict()
            else:
                params['action_url'] = self.action_url
        if self.ad_id:
            if hasattr(self.ad_id, 'to_alipay_dict'):
                params['ad_id'] = self.ad_id.to_alipay_dict()
            else:
                params['ad_id'] = self.ad_id
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.height:
            if hasattr(self.height, 'to_alipay_dict'):
                params['height'] = self.height.to_alipay_dict()
            else:
                params['height'] = self.height
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingAdvertisingModifyModel()
        if 'action_url' in d:
            o.action_url = d['action_url']
        if 'ad_id' in d:
            o.ad_id = d['ad_id']
        if 'content' in d:
            o.content = d['content']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'height' in d:
            o.height = d['height']
        if 'start_time' in d:
            o.start_time = d['start_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserAccountInvitedConvertSyncResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserAccountInvitedConvertSyncResponse, self).__init__()
        self._result_code = None
        self._result_desc = None
        self._success = None

    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_desc(self):
        return self._result_desc

    @result_desc.setter
    def result_desc(self, value):
        self._result_desc = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserAccountInvitedConvertSyncResponse, self).parse_response_content(response_content)
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_desc' in response:
            self.result_desc = response['result_desc']
        if 'success' in response:
            self.success = response['success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TicketDetailInfo(object):

    def __init__(self):
        self._amount = None
        self._end_station = None
        self._end_station_name = None
        self._quantity = None
        self._start_station = None
        self._start_station_name = None
        self._status = None
        self._ticket_price = None
        self._ticket_type = None
        self._trade_no = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def end_station(self):
        return self._end_station

    @end_station.setter
    def end_station(self, value):
        self._end_station = value
    @property
    def end_station_name(self):
        return self._end_station_name

    @end_station_name.setter
    def end_station_name(self, value):
        self._end_station_name = value
    @property
    def quantity(self):
        return self._quantity

    @quantity.setter
    def quantity(self, value):
        self._quantity = value
    @property
    def start_station(self):
        return self._start_station

    @start_station.setter
    def start_station(self, value):
        self._start_station = value
    @property
    def start_station_name(self):
        return self._start_station_name

    @start_station_name.setter
    def start_station_name(self, value):
        self._start_station_name = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def ticket_price(self):
        return self._ticket_price

    @ticket_price.setter
    def ticket_price(self, value):
        self._ticket_price = value
    @property
    def ticket_type(self):
        return self._ticket_type

    @ticket_type.setter
    def ticket_type(self, value):
        self._ticket_type = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.end_station:
            if hasattr(self.end_station, 'to_alipay_dict'):
                params['end_station'] = self.end_station.to_alipay_dict()
            else:
                params['end_station'] = self.end_station
        if self.end_station_name:
            if hasattr(self.end_station_name, 'to_alipay_dict'):
                params['end_station_name'] = self.end_station_name.to_alipay_dict()
            else:
                params['end_station_name'] = self.end_station_name
        if self.quantity:
            if hasattr(self.quantity, 'to_alipay_dict'):
                params['quantity'] = self.quantity.to_alipay_dict()
            else:
                params['quantity'] = self.quantity
        if self.start_station:
            if hasattr(self.start_station, 'to_alipay_dict'):
                params['start_station'] = self.start_station.to_alipay_dict()
            else:
                params['start_station'] = self.start_station
        if self.start_station_name:
            if hasattr(self.start_station_name, 'to_alipay_dict'):
                params['start_station_name'] = self.start_station_name.to_alipay_dict()
            else:
                params['start_station_name'] = self.start_station_name
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.ticket_price:
            if hasattr(self.ticket_price, 'to_alipay_dict'):
                params['ticket_price'] = self.ticket_price.to_alipay_dict()
            else:
                params['ticket_price'] = self.ticket_price
        if self.ticket_type:
            if hasattr(self.ticket_type, 'to_alipay_dict'):
                params['ticket_type'] = self.ticket_type.to_alipay_dict()
            else:
                params['ticket_type'] = self.ticket_type
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TicketDetailInfo()
        if 'amount' in d:
            o.amount = d['amount']
        if 'end_station' in d:
            o.end_station = d['end_station']
        if 'end_station_name' in d:
            o.end_station_name = d['end_station_name']
        if 'quantity' in d:
            o.quantity = d['quantity']
        if 'start_station' in d:
            o.start_station = d['start_station']
        if 'start_station_name' in d:
            o.start_station_name = d['start_station_name']
        if 'status' in d:
            o.status = d['status']
        if 'ticket_price' in d:
            o.ticket_price = d['ticket_price']
        if 'ticket_type' in d:
            o.ticket_type = d['ticket_type']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GavintestNewLeveaOne import GavintestNewLeveaOne


class AlipayOpenDesCreateModel(object):

    def __init__(self):
        self._des = None
        self._test = None

    @property
    def des(self):
        return self._des

    @des.setter
    def des(self, value):
        if isinstance(value, list):
            self._des = list()
            for i in value:
                if isinstance(i, GavintestNewLeveaOne):
                    self._des.append(i)
                else:
                    self._des.append(GavintestNewLeveaOne.from_alipay_dict(i))
    @property
    def test(self):
        return self._test

    @test.setter
    def test(self, value):
        if isinstance(value, list):
            self._test = list()
            for i in value:
                self._test.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.des:
            if isinstance(self.des, list):
                for i in range(0, len(self.des)):
                    element = self.des[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.des[i] = element.to_alipay_dict()
            if hasattr(self.des, 'to_alipay_dict'):
                params['des'] = self.des.to_alipay_dict()
            else:
                params['des'] = self.des
        if self.test:
            if isinstance(self.test, list):
                for i in range(0, len(self.test)):
                    element = self.test[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.test[i] = element.to_alipay_dict()
            if hasattr(self.test, 'to_alipay_dict'):
                params['test'] = self.test.to_alipay_dict()
            else:
                params['test'] = self.test
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenDesCreateModel()
        if 'des' in d:
            o.des = d['des']
        if 'test' in d:
            o.test = d['test']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AgmTagDTO(object):

    def __init__(self):
        self._name = None
        self._voucher_id = None

    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def voucher_id(self):
        return self._voucher_id

    @voucher_id.setter
    def voucher_id(self, value):
        self._voucher_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.voucher_id:
            if hasattr(self.voucher_id, 'to_alipay_dict'):
                params['voucher_id'] = self.voucher_id.to_alipay_dict()
            else:
                params['voucher_id'] = self.voucher_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AgmTagDTO()
        if 'name' in d:
            o.name = d['name']
        if 'voucher_id' in d:
            o.voucher_id = d['voucher_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InsSellerActivity(object):

    def __init__(self):
        self._biz_data = None
        self._join_time = None
        self._status = None

    @property
    def biz_data(self):
        return self._biz_data

    @biz_data.setter
    def biz_data(self, value):
        self._biz_data = value
    @property
    def join_time(self):
        return self._join_time

    @join_time.setter
    def join_time(self, value):
        self._join_time = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_data:
            if hasattr(self.biz_data, 'to_alipay_dict'):
                params['biz_data'] = self.biz_data.to_alipay_dict()
            else:
                params['biz_data'] = self.biz_data
        if self.join_time:
            if hasattr(self.join_time, 'to_alipay_dict'):
                params['join_time'] = self.join_time.to_alipay_dict()
            else:
                params['join_time'] = self.join_time
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsSellerActivity()
        if 'biz_data' in d:
            o.biz_data = d['biz_data']
        if 'join_time' in d:
            o.join_time = d['join_time']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.LoanChargeInfo import LoanChargeInfo
from alipay.aop.api.domain.InstallmentMetaInfo import InstallmentMetaInfo
from alipay.aop.api.domain.InstallmentMetaInfo import InstallmentMetaInfo


class ApproveCreditResult(object):

    def __init__(self):
        self._charge_info_list = None
        self._credit_amt = None
        self._credit_no = None
        self._credit_term = None
        self._expire_date = None
        self._instal_int_rate = None
        self._loan_term = None
        self._repay_modes = None
        self._start_date = None
        self._status = None

    @property
    def charge_info_list(self):
        return self._charge_info_list

    @charge_info_list.setter
    def charge_info_list(self, value):
        if isinstance(value, list):
            self._charge_info_list = list()
            for i in value:
                if isinstance(i, LoanChargeInfo):
                    self._charge_info_list.append(i)
                else:
                    self._charge_info_list.append(LoanChargeInfo.from_alipay_dict(i))
    @property
    def credit_amt(self):
        return self._credit_amt

    @credit_amt.setter
    def credit_amt(self, value):
        self._credit_amt = value
    @property
    def credit_no(self):
        return self._credit_no

    @credit_no.setter
    def credit_no(self, value):
        self._credit_no = value
    @property
    def credit_term(self):
        return self._credit_term

    @credit_term.setter
    def credit_term(self, value):
        self._credit_term = value
    @property
    def expire_date(self):
        return self._expire_date

    @expire_date.setter
    def expire_date(self, value):
        self._expire_date = value
    @property
    def instal_int_rate(self):
        return self._instal_int_rate

    @instal_int_rate.setter
    def instal_int_rate(self, value):
        if isinstance(value, list):
            self._instal_int_rate = list()
            for i in value:
                if isinstance(i, InstallmentMetaInfo):
                    self._instal_int_rate.append(i)
                else:
                    self._instal_int_rate.append(InstallmentMetaInfo.from_alipay_dict(i))
    @property
    def loan_term(self):
        return self._loan_term

    @loan_term.setter
    def loan_term(self, value):
        self._loan_term = value
    @property
    def repay_modes(self):
        return self._repay_modes

    @repay_modes.setter
    def repay_modes(self, value):
        if isinstance(value, list):
            self._repay_modes = list()
            for i in value:
                if isinstance(i, InstallmentMetaInfo):
                    self._repay_modes.append(i)
                else:
                    self._repay_modes.append(InstallmentMetaInfo.from_alipay_dict(i))
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.charge_info_list:
            if isinstance(self.charge_info_list, list):
                for i in range(0, len(self.charge_info_list)):
                    element = self.charge_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.charge_info_list[i] = element.to_alipay_dict()
            if hasattr(self.charge_info_list, 'to_alipay_dict'):
                params['charge_info_list'] = self.charge_info_list.to_alipay_dict()
            else:
                params['charge_info_list'] = self.charge_info_list
        if self.credit_amt:
            if hasattr(self.credit_amt, 'to_alipay_dict'):
                params['credit_amt'] = self.credit_amt.to_alipay_dict()
            else:
                params['credit_amt'] = self.credit_amt
        if self.credit_no:
            if hasattr(self.credit_no, 'to_alipay_dict'):
                params['credit_no'] = self.credit_no.to_alipay_dict()
            else:
                params['credit_no'] = self.credit_no
        if self.credit_term:
            if hasattr(self.credit_term, 'to_alipay_dict'):
                params['credit_term'] = self.credit_term.to_alipay_dict()
            else:
                params['credit_term'] = self.credit_term
        if self.expire_date:
            if hasattr(self.expire_date, 'to_alipay_dict'):
                params['expire_date'] = self.expire_date.to_alipay_dict()
            else:
                params['expire_date'] = self.expire_date
        if self.instal_int_rate:
            if isinstance(self.instal_int_rate, list):
                for i in range(0, len(self.instal_int_rate)):
                    element = self.instal_int_rate[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.instal_int_rate[i] = element.to_alipay_dict()
            if hasattr(self.instal_int_rate, 'to_alipay_dict'):
                params['instal_int_rate'] = self.instal_int_rate.to_alipay_dict()
            else:
                params['instal_int_rate'] = self.instal_int_rate
        if self.loan_term:
            if hasattr(self.loan_term, 'to_alipay_dict'):
                params['loan_term'] = self.loan_term.to_alipay_dict()
            else:
                params['loan_term'] = self.loan_term
        if self.repay_modes:
            if isinstance(self.repay_modes, list):
                for i in range(0, len(self.repay_modes)):
                    element = self.repay_modes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.repay_modes[i] = element.to_alipay_dict()
            if hasattr(self.repay_modes, 'to_alipay_dict'):
                params['repay_modes'] = self.repay_modes.to_alipay_dict()
            else:
                params['repay_modes'] = self.repay_modes
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ApproveCreditResult()
        if 'charge_info_list' in d:
            o.charge_info_list = d['charge_info_list']
        if 'credit_amt' in d:
            o.credit_amt = d['credit_amt']
        if 'credit_no' in d:
            o.credit_no = d['credit_no']
        if 'credit_term' in d:
            o.credit_term = d['credit_term']
        if 'expire_date' in d:
            o.expire_date = d['expire_date']
        if 'instal_int_rate' in d:
            o.instal_int_rate = d['instal_int_rate']
        if 'loan_term' in d:
            o.loan_term = d['loan_term']
        if 'repay_modes' in d:
            o.repay_modes = d['repay_modes']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PreCreateWaybillIstd import PreCreateWaybillIstd


class AlipayCommerceLogisticsOrderInstantdeliveryPrecreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceLogisticsOrderInstantdeliveryPrecreateResponse, self).__init__()
        self._waybills = None

    @property
    def waybills(self):
        return self._waybills

    @waybills.setter
    def waybills(self, value):
        if isinstance(value, list):
            self._waybills = list()
            for i in value:
                if isinstance(i, PreCreateWaybillIstd):
                    self._waybills.append(i)
                else:
                    self._waybills.append(PreCreateWaybillIstd.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceLogisticsOrderInstantdeliveryPrecreateResponse, self).parse_response_content(response_content)
        if 'waybills' in response:
            self.waybills = response['waybills']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceEducateFacefeatureInfoSendResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceEducateFacefeatureInfoSendResponse, self).__init__()
        self._error_uids = None

    @property
    def error_uids(self):
        return self._error_uids

    @error_uids.setter
    def error_uids(self, value):
        self._error_uids = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceEducateFacefeatureInfoSendResponse, self).parse_response_content(response_content)
        if 'error_uids' in response:
            self.error_uids = response['error_uids']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.VoucherConsultInfo import VoucherConsultInfo


class AlipayMarketingAssetPreconsultResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingAssetPreconsultResponse, self).__init__()
        self._optimal_total_promo_amount = None
        self._voucher_consult_list = None

    @property
    def optimal_total_promo_amount(self):
        return self._optimal_total_promo_amount

    @optimal_total_promo_amount.setter
    def optimal_total_promo_amount(self, value):
        self._optimal_total_promo_amount = value
    @property
    def voucher_consult_list(self):
        return self._voucher_consult_list

    @voucher_consult_list.setter
    def voucher_consult_list(self, value):
        if isinstance(value, list):
            self._voucher_consult_list = list()
            for i in value:
                if isinstance(i, VoucherConsultInfo):
                    self._voucher_consult_list.append(i)
                else:
                    self._voucher_consult_list.append(VoucherConsultInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingAssetPreconsultResponse, self).parse_response_content(response_content)
        if 'optimal_total_promo_amount' in response:
            self.optimal_total_promo_amount = response['optimal_total_promo_amount']
        if 'voucher_consult_list' in response:
            self.voucher_consult_list = response['voucher_consult_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SearchOpenStatusRequest(object):

    def __init__(self):
        self._action = None
        self._apply_type = None
        self._box_id = None
        self._close_reason = None
        self._service_code = None

    @property
    def action(self):
        return self._action

    @action.setter
    def action(self, value):
        self._action = value
    @property
    def apply_type(self):
        return self._apply_type

    @apply_type.setter
    def apply_type(self, value):
        self._apply_type = value
    @property
    def box_id(self):
        return self._box_id

    @box_id.setter
    def box_id(self, value):
        self._box_id = value
    @property
    def close_reason(self):
        return self._close_reason

    @close_reason.setter
    def close_reason(self, value):
        self._close_reason = value
    @property
    def service_code(self):
        return self._service_code

    @service_code.setter
    def service_code(self, value):
        self._service_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.action:
            if hasattr(self.action, 'to_alipay_dict'):
                params['action'] = self.action.to_alipay_dict()
            else:
                params['action'] = self.action
        if self.apply_type:
            if hasattr(self.apply_type, 'to_alipay_dict'):
                params['apply_type'] = self.apply_type.to_alipay_dict()
            else:
                params['apply_type'] = self.apply_type
        if self.box_id:
            if hasattr(self.box_id, 'to_alipay_dict'):
                params['box_id'] = self.box_id.to_alipay_dict()
            else:
                params['box_id'] = self.box_id
        if self.close_reason:
            if hasattr(self.close_reason, 'to_alipay_dict'):
                params['close_reason'] = self.close_reason.to_alipay_dict()
            else:
                params['close_reason'] = self.close_reason
        if self.service_code:
            if hasattr(self.service_code, 'to_alipay_dict'):
                params['service_code'] = self.service_code.to_alipay_dict()
            else:
                params['service_code'] = self.service_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SearchOpenStatusRequest()
        if 'action' in d:
            o.action = d['action']
        if 'apply_type' in d:
            o.apply_type = d['apply_type']
        if 'box_id' in d:
            o.box_id = d['box_id']
        if 'close_reason' in d:
            o.close_reason = d['close_reason']
        if 'service_code' in d:
            o.service_code = d['service_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BusinessRelationShopTradeDetailInfo import BusinessRelationShopTradeDetailInfo


class AlipayBusinessRelationTradedetailBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBusinessRelationTradedetailBatchqueryResponse, self).__init__()
        self._real_shop_id = None
        self._real_shop_no = None
        self._shop_confirm_status = None
        self._shop_name = None
        self._shop_trade_data_detail_infos = None
        self._total_num = None

    @property
    def real_shop_id(self):
        return self._real_shop_id

    @real_shop_id.setter
    def real_shop_id(self, value):
        self._real_shop_id = value
    @property
    def real_shop_no(self):
        return self._real_shop_no

    @real_shop_no.setter
    def real_shop_no(self, value):
        self._real_shop_no = value
    @property
    def shop_confirm_status(self):
        return self._shop_confirm_status

    @shop_confirm_status.setter
    def shop_confirm_status(self, value):
        self._shop_confirm_status = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def shop_trade_data_detail_infos(self):
        return self._shop_trade_data_detail_infos

    @shop_trade_data_detail_infos.setter
    def shop_trade_data_detail_infos(self, value):
        if isinstance(value, list):
            self._shop_trade_data_detail_infos = list()
            for i in value:
                if isinstance(i, BusinessRelationShopTradeDetailInfo):
                    self._shop_trade_data_detail_infos.append(i)
                else:
                    self._shop_trade_data_detail_infos.append(BusinessRelationShopTradeDetailInfo.from_alipay_dict(i))
    @property
    def total_num(self):
        return self._total_num

    @total_num.setter
    def total_num(self, value):
        self._total_num = value

    def parse_response_content(self, response_content):
        response = super(AlipayBusinessRelationTradedetailBatchqueryResponse, self).parse_response_content(response_content)
        if 'real_shop_id' in response:
            self.real_shop_id = response['real_shop_id']
        if 'real_shop_no' in response:
            self.real_shop_no = response['real_shop_no']
        if 'shop_confirm_status' in response:
            self.shop_confirm_status = response['shop_confirm_status']
        if 'shop_name' in response:
            self.shop_name = response['shop_name']
        if 'shop_trade_data_detail_infos' in response:
            self.shop_trade_data_detail_infos = response['shop_trade_data_detail_infos']
        if 'total_num' in response:
            self.total_num = response['total_num']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoRenthouseBill(object):

    def __init__(self):
        self._bill_amount = None
        self._bill_create_time = None
        self._bill_desc = None
        self._bill_no = None
        self._bill_status = None
        self._bill_type = None
        self._deadline_date = None
        self._deduction_amount = None
        self._discount_amount = None
        self._end_date = None
        self._lease_no = None
        self._memo = None
        self._min_pay_amount = None
        self._paid_amount = None
        self._pay_lock = None
        self._pay_lock_memo = None
        self._pay_status = None
        self._pay_time = None
        self._start_date = None

    @property
    def bill_amount(self):
        return self._bill_amount

    @bill_amount.setter
    def bill_amount(self, value):
        self._bill_amount = value
    @property
    def bill_create_time(self):
        return self._bill_create_time

    @bill_create_time.setter
    def bill_create_time(self, value):
        self._bill_create_time = value
    @property
    def bill_desc(self):
        return self._bill_desc

    @bill_desc.setter
    def bill_desc(self, value):
        self._bill_desc = value
    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def bill_status(self):
        return self._bill_status

    @bill_status.setter
    def bill_status(self, value):
        self._bill_status = value
    @property
    def bill_type(self):
        return self._bill_type

    @bill_type.setter
    def bill_type(self, value):
        self._bill_type = value
    @property
    def deadline_date(self):
        return self._deadline_date

    @deadline_date.setter
    def deadline_date(self, value):
        self._deadline_date = value
    @property
    def deduction_amount(self):
        return self._deduction_amount

    @deduction_amount.setter
    def deduction_amount(self, value):
        self._deduction_amount = value
    @property
    def discount_amount(self):
        return self._discount_amount

    @discount_amount.setter
    def discount_amount(self, value):
        self._discount_amount = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def lease_no(self):
        return self._lease_no

    @lease_no.setter
    def lease_no(self, value):
        self._lease_no = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def min_pay_amount(self):
        return self._min_pay_amount

    @min_pay_amount.setter
    def min_pay_amount(self, value):
        self._min_pay_amount = value
    @property
    def paid_amount(self):
        return self._paid_amount

    @paid_amount.setter
    def paid_amount(self, value):
        self._paid_amount = value
    @property
    def pay_lock(self):
        return self._pay_lock

    @pay_lock.setter
    def pay_lock(self, value):
        self._pay_lock = value
    @property
    def pay_lock_memo(self):
        return self._pay_lock_memo

    @pay_lock_memo.setter
    def pay_lock_memo(self, value):
        self._pay_lock_memo = value
    @property
    def pay_status(self):
        return self._pay_status

    @pay_status.setter
    def pay_status(self, value):
        self._pay_status = value
    @property
    def pay_time(self):
        return self._pay_time

    @pay_time.setter
    def pay_time(self, value):
        self._pay_time = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.bill_amount:
            if hasattr(self.bill_amount, 'to_alipay_dict'):
                params['bill_amount'] = self.bill_amount.to_alipay_dict()
            else:
                params['bill_amount'] = self.bill_amount
        if self.bill_create_time:
            if hasattr(self.bill_create_time, 'to_alipay_dict'):
                params['bill_create_time'] = self.bill_create_time.to_alipay_dict()
            else:
                params['bill_create_time'] = self.bill_create_time
        if self.bill_desc:
            if hasattr(self.bill_desc, 'to_alipay_dict'):
                params['bill_desc'] = self.bill_desc.to_alipay_dict()
            else:
                params['bill_desc'] = self.bill_desc
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.bill_status:
            if hasattr(self.bill_status, 'to_alipay_dict'):
                params['bill_status'] = self.bill_status.to_alipay_dict()
            else:
                params['bill_status'] = self.bill_status
        if self.bill_type:
            if hasattr(self.bill_type, 'to_alipay_dict'):
                params['bill_type'] = self.bill_type.to_alipay_dict()
            else:
                params['bill_type'] = self.bill_type
        if self.deadline_date:
            if hasattr(self.deadline_date, 'to_alipay_dict'):
                params['deadline_date'] = self.deadline_date.to_alipay_dict()
            else:
                params['deadline_date'] = self.deadline_date
        if self.deduction_amount:
            if hasattr(self.deduction_amount, 'to_alipay_dict'):
                params['deduction_amount'] = self.deduction_amount.to_alipay_dict()
            else:
                params['deduction_amount'] = self.deduction_amount
        if self.discount_amount:
            if hasattr(self.discount_amount, 'to_alipay_dict'):
                params['discount_amount'] = self.discount_amount.to_alipay_dict()
            else:
                params['discount_amount'] = self.discount_amount
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.lease_no:
            if hasattr(self.lease_no, 'to_alipay_dict'):
                params['lease_no'] = self.lease_no.to_alipay_dict()
            else:
                params['lease_no'] = self.lease_no
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.min_pay_amount:
            if hasattr(self.min_pay_amount, 'to_alipay_dict'):
                params['min_pay_amount'] = self.min_pay_amount.to_alipay_dict()
            else:
                params['min_pay_amount'] = self.min_pay_amount
        if self.paid_amount:
            if hasattr(self.paid_amount, 'to_alipay_dict'):
                params['paid_amount'] = self.paid_amount.to_alipay_dict()
            else:
                params['paid_amount'] = self.paid_amount
        if self.pay_lock:
            if hasattr(self.pay_lock, 'to_alipay_dict'):
                params['pay_lock'] = self.pay_lock.to_alipay_dict()
            else:
                params['pay_lock'] = self.pay_lock
        if self.pay_lock_memo:
            if hasattr(self.pay_lock_memo, 'to_alipay_dict'):
                params['pay_lock_memo'] = self.pay_lock_memo.to_alipay_dict()
            else:
                params['pay_lock_memo'] = self.pay_lock_memo
        if self.pay_status:
            if hasattr(self.pay_status, 'to_alipay_dict'):
                params['pay_status'] = self.pay_status.to_alipay_dict()
            else:
                params['pay_status'] = self.pay_status
        if self.pay_time:
            if hasattr(self.pay_time, 'to_alipay_dict'):
                params['pay_time'] = self.pay_time.to_alipay_dict()
            else:
                params['pay_time'] = self.pay_time
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoRenthouseBill()
        if 'bill_amount' in d:
            o.bill_amount = d['bill_amount']
        if 'bill_create_time' in d:
            o.bill_create_time = d['bill_create_time']
        if 'bill_desc' in d:
            o.bill_desc = d['bill_desc']
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'bill_status' in d:
            o.bill_status = d['bill_status']
        if 'bill_type' in d:
            o.bill_type = d['bill_type']
        if 'deadline_date' in d:
            o.deadline_date = d['deadline_date']
        if 'deduction_amount' in d:
            o.deduction_amount = d['deduction_amount']
        if 'discount_amount' in d:
            o.discount_amount = d['discount_amount']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'lease_no' in d:
            o.lease_no = d['lease_no']
        if 'memo' in d:
            o.memo = d['memo']
        if 'min_pay_amount' in d:
            o.min_pay_amount = d['min_pay_amount']
        if 'paid_amount' in d:
            o.paid_amount = d['paid_amount']
        if 'pay_lock' in d:
            o.pay_lock = d['pay_lock']
        if 'pay_lock_memo' in d:
            o.pay_lock_memo = d['pay_lock_memo']
        if 'pay_status' in d:
            o.pay_status = d['pay_status']
        if 'pay_time' in d:
            o.pay_time = d['pay_time']
        if 'start_date' in d:
            o.start_date = d['start_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAgentSignstatusQueryModel(object):

    def __init__(self):
        self._pid = None
        self._product_codes = None

    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def product_codes(self):
        return self._product_codes

    @product_codes.setter
    def product_codes(self, value):
        if isinstance(value, list):
            self._product_codes = list()
            for i in value:
                self._product_codes.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.product_codes:
            if isinstance(self.product_codes, list):
                for i in range(0, len(self.product_codes)):
                    element = self.product_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.product_codes[i] = element.to_alipay_dict()
            if hasattr(self.product_codes, 'to_alipay_dict'):
                params['product_codes'] = self.product_codes.to_alipay_dict()
            else:
                params['product_codes'] = self.product_codes
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAgentSignstatusQueryModel()
        if 'pid' in d:
            o.pid = d['pid']
        if 'product_codes' in d:
            o.product_codes = d['product_codes']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPcreditUserOpencoremodeltestXinghuiModifyModel(object):

    def __init__(self):
        self._a = None
        self._b = None

    @property
    def a(self):
        return self._a

    @a.setter
    def a(self, value):
        self._a = value
    @property
    def b(self):
        return self._b

    @b.setter
    def b(self, value):
        self._b = value


    def to_alipay_dict(self):
        params = dict()
        if self.a:
            if hasattr(self.a, 'to_alipay_dict'):
                params['a'] = self.a.to_alipay_dict()
            else:
                params['a'] = self.a
        if self.b:
            if hasattr(self.b, 'to_alipay_dict'):
                params['b'] = self.b.to_alipay_dict()
            else:
                params['b'] = self.b
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditUserOpencoremodeltestXinghuiModifyModel()
        if 'a' in d:
            o.a = d['a']
        if 'b' in d:
            o.b = d['b']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.IntlBrandInfo import IntlBrandInfo
from alipay.aop.api.domain.ExternalInfo import ExternalInfo


class AlipayOverseasTravelIntlBrandSyncModel(object):

    def __init__(self):
        self._brand_info = None
        self._external_list = None
        self._request_id = None

    @property
    def brand_info(self):
        return self._brand_info

    @brand_info.setter
    def brand_info(self, value):
        if isinstance(value, IntlBrandInfo):
            self._brand_info = value
        else:
            self._brand_info = IntlBrandInfo.from_alipay_dict(value)
    @property
    def external_list(self):
        return self._external_list

    @external_list.setter
    def external_list(self, value):
        if isinstance(value, list):
            self._external_list = list()
            for i in value:
                if isinstance(i, ExternalInfo):
                    self._external_list.append(i)
                else:
                    self._external_list.append(ExternalInfo.from_alipay_dict(i))
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand_info:
            if hasattr(self.brand_info, 'to_alipay_dict'):
                params['brand_info'] = self.brand_info.to_alipay_dict()
            else:
                params['brand_info'] = self.brand_info
        if self.external_list:
            if isinstance(self.external_list, list):
                for i in range(0, len(self.external_list)):
                    element = self.external_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.external_list[i] = element.to_alipay_dict()
            if hasattr(self.external_list, 'to_alipay_dict'):
                params['external_list'] = self.external_list.to_alipay_dict()
            else:
                params['external_list'] = self.external_list
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOverseasTravelIntlBrandSyncModel()
        if 'brand_info' in d:
            o.brand_info = d['brand_info']
        if 'external_list' in d:
            o.external_list = d['external_list']
        if 'request_id' in d:
            o.request_id = d['request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.XwbTestData import XwbTestData


class AlipayOpenServicemarketYcstestQueryModel(object):

    def __init__(self):
        self._in_1 = None
        self._in_2 = None
        self._in_3 = None
        self._in_4 = None
        self._in_5 = None
        self._in_6 = None

    @property
    def in_1(self):
        return self._in_1

    @in_1.setter
    def in_1(self, value):
        self._in_1 = value
    @property
    def in_2(self):
        return self._in_2

    @in_2.setter
    def in_2(self, value):
        self._in_2 = value
    @property
    def in_3(self):
        return self._in_3

    @in_3.setter
    def in_3(self, value):
        self._in_3 = value
    @property
    def in_4(self):
        return self._in_4

    @in_4.setter
    def in_4(self, value):
        self._in_4 = value
    @property
    def in_5(self):
        return self._in_5

    @in_5.setter
    def in_5(self, value):
        self._in_5 = value
    @property
    def in_6(self):
        return self._in_6

    @in_6.setter
    def in_6(self, value):
        if isinstance(value, XwbTestData):
            self._in_6 = value
        else:
            self._in_6 = XwbTestData.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.in_1:
            if hasattr(self.in_1, 'to_alipay_dict'):
                params['in_1'] = self.in_1.to_alipay_dict()
            else:
                params['in_1'] = self.in_1
        if self.in_2:
            if hasattr(self.in_2, 'to_alipay_dict'):
                params['in_2'] = self.in_2.to_alipay_dict()
            else:
                params['in_2'] = self.in_2
        if self.in_3:
            if hasattr(self.in_3, 'to_alipay_dict'):
                params['in_3'] = self.in_3.to_alipay_dict()
            else:
                params['in_3'] = self.in_3
        if self.in_4:
            if hasattr(self.in_4, 'to_alipay_dict'):
                params['in_4'] = self.in_4.to_alipay_dict()
            else:
                params['in_4'] = self.in_4
        if self.in_5:
            if hasattr(self.in_5, 'to_alipay_dict'):
                params['in_5'] = self.in_5.to_alipay_dict()
            else:
                params['in_5'] = self.in_5
        if self.in_6:
            if hasattr(self.in_6, 'to_alipay_dict'):
                params['in_6'] = self.in_6.to_alipay_dict()
            else:
                params['in_6'] = self.in_6
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenServicemarketYcstestQueryModel()
        if 'in_1' in d:
            o.in_1 = d['in_1']
        if 'in_2' in d:
            o.in_2 = d['in_2']
        if 'in_3' in d:
            o.in_3 = d['in_3']
        if 'in_4' in d:
            o.in_4 = d['in_4']
        if 'in_5' in d:
            o.in_5 = d['in_5']
        if 'in_6' in d:
            o.in_6 = d['in_6']
        return o


